@@ -29,7 +29,7 @@
 /* locate the center and size of the movement. */
 struct coord alg_locate_center_size(struct images *imgs, int width, int height)
 {
-	char *out=imgs->out;
+	unsigned char *out=imgs->out;
 	int *labels=imgs->labels;
 	int x, y, centc=0, xdist=0, ydist=0;
 	struct coord cent;
@@ -41,12 +41,12 @@ struct coord alg_locate_center_size(struct images *imgs, int width, int height)
 	cent.minx=width;
 	cent.miny=height;
 	
-	/* If Labeling enabled - locate center of largest label */
+	/* If Labeling enabled - locate center of largest labelgroup */
 	if (imgs->labelsize_max) {
-		/* Locate largest label */
+		/* Locate largest labelgroup */
 		for (y=0; y<height; y++) {
 			for (x=0; x<width; x++) {
-				if (*(labels++) == imgs->largest_label) {
+				if (*(labels++)&32768) {
 					cent.x += x;
 					cent.y += y;
 					centc++;
@@ -72,16 +72,16 @@ struct coord alg_locate_center_size(struct images *imgs, int width, int height)
 	
 	/* Now we find the size of the Motion */
 
-	/* First reset pointers back to initial value */	
+	/* First reset pointers back to initial value */
 	centc=0;
 	labels=imgs->labels;
 	out=imgs->out;
 
-	/* If Labeling then we find the area around largest label instead */
+	/* If Labeling then we find the area around largest labelgroup instead */
 	if (imgs->labelsize_max) {
 		for (y=0; y<height; y++) {
 			for (x=0; x<width; x++) {
-				if (*(labels++)==imgs->largest_label) {
+				if (*(labels++)&32768) {
 					if (x > cent.x)
 						xdist += x - cent.x;
 					else if (x < cent.x)
@@ -151,36 +151,48 @@ struct coord alg_locate_center_size(struct images *imgs, int width, int height)
 
 
 /* draw a box around the movement */
-void alg_draw_location(struct coord *cent, struct images *imgs, int width, int height, char *new, int mode)
+void alg_draw_location(struct coord *cent, struct images *imgs, int width, int height, unsigned char *new, int mode)
 {
-	char *out=imgs->out;
+	unsigned char *out=imgs->out;
 	int x, y;
 
 	out=imgs->out;
 	
 	/* Draw a box around the movement */
 	if (mode == LOCATE_BOTH){ /* both normal and motion image gets a box */
+		int width_miny = width*cent->miny;
+		int width_maxy = width*cent->maxy;
 		for (x=cent->minx; x<=cent->maxx; x++) {
-			new[x+width*cent->miny]=~new[x+width*cent->miny];
-			new[x+width*cent->maxy]=~new[x+width*cent->maxy];
-			out[x+width*cent->miny]=~out[x+width*cent->miny];
-			out[x+width*cent->maxy]=~out[x+width*cent->maxy];
+			int width_miny_x = x+width_miny;
+			int width_maxy_x = x+width_maxy;
+			new[width_miny_x]=~new[width_miny_x];
+			new[width_maxy_x]=~new[width_maxy_x];
+			out[width_miny_x]=~out[width_miny_x];
+			out[width_maxy_x]=~out[width_maxy_x];
 		}
 		for (y=cent->miny; y<=cent->maxy; y++) {
-			new[cent->minx+y*width]=~new[cent->minx+y*width];
-			new[cent->maxx+y*width]=~new[cent->maxx+y*width];
-			out[cent->minx+y*width]=~out[cent->minx+y*width];
-			out[cent->maxx+y*width]=~out[cent->maxx+y*width];
+			int width_minx_y = cent->minx+y*width; 
+			int width_maxx_y = cent->maxx+y*width;
+			new[width_minx_y]=~new[width_minx_y];
+			new[width_maxx_y]=~new[width_maxx_y];
+			out[width_minx_y]=~out[width_minx_y];
+			out[width_maxx_y]=~out[width_maxx_y];
 		}
 	}
 	else{ /* normal image only (e.g. preview shot) */
+		int width_miny = width*cent->miny;
+		int width_maxy = width*cent->maxy;
 		for (x=cent->minx; x<=cent->maxx; x++) {
-			new[x+width*cent->miny]=~new[x+width*cent->miny];
-			new[x+width*cent->maxy]=~new[x+width*cent->maxy];
+			int width_miny_x = width_miny+x;
+			int width_maxy_x = width_maxy+x;
+			new[width_miny_x]=~new[width_miny_x];
+			new[width_maxy_x]=~new[width_maxy_x];
 		}
 		for (y=cent->miny; y<=cent->maxy; y++) {
-			new[cent->minx+y*width]=~new[cent->minx+y*width];
-			new[cent->maxx+y*width]=~new[cent->maxx+y*width];
+			int minx_y = cent->minx+y*width;
+			int maxx_y = cent->maxx+y*width;
+			new[minx_y]=~new[minx_y];
+			new[maxx_y]=~new[maxx_y];
 		}
 	}
 }
@@ -208,7 +220,7 @@ void alg_noise_tune (struct context *cnt, unsigned char *new)
 		diff=*ref-*new;
 		
 		if (mask)
-			diff=((diff**mask++)/255);
+			diff=((diff* *mask++)/255);
 
 		if (*smartmask){
 			sum+=ABS(diff)+1;
@@ -220,13 +232,13 @@ void alg_noise_tune (struct context *cnt, unsigned char *new)
 		smartmask++;
 	}
 	
-	if (count>4) //avoid divide by zero
+	if (count>4) /* avoid divide by zero */
 		sum/=count/4;
 		
 	cnt->noise=4+(cnt->noise+sum)/2;
 }
 
-void alg_threshold_tune (struct context *cnt, int diffs, int motion)
+void alg_threshold_tune(struct context *cnt, int diffs, int motion)
 {
 	int i;
 	int sum=0, top=diffs;
@@ -282,7 +294,7 @@ typedef struct {short y, xl, xr, dy;} Segment;
 
 
 static int iflood(int x, int y,       /* seed point */
-                  int width, int height, char *out, int *labels, int newvalue)
+                  int width, int height, unsigned char *out, int *labels, int newvalue, int oldvalue)
 {
 	int l, x1, x2, dy;
 	Segment stack[MAXS], *sp = stack;    /* stack of filled segments */
@@ -301,7 +313,7 @@ static int iflood(int x, int y,       /* seed point */
 		 * segment of scan line y-dy for x1<=x<=x2 was previously filled,
 		 * now explore adjacent pixels in scan line y
 		 */
-		for (x = x1; x >= 0 && out[y*width+x] != 0 && labels[y*width+x] == 0; x--) {
+		for (x = x1; x >= 0 && out[y*width+x] != 0 && labels[y*width+x] == oldvalue; x--) {
 			labels[y*width+x] = newvalue;
 			count++;
 		}
@@ -317,15 +329,20 @@ static int iflood(int x, int y,       /* seed point */
 		x = x1 + 1;
 		
 		do {
-			for (; x < width && out[y*width+x] != 0 && labels[y*width+x]==0; x++){
+			for (; x < width && out[y*width+x] != 0 && labels[y*width+x]==oldvalue; x++) {
 				labels[y*width+x] = newvalue;
 				count++;
 			}
+			
 			PUSH(y, l, x-1, dy);
+			
 			if (x > x2+1)
 				PUSH(y, x2+1, x-1, -dy);  /* leak on right? */
+			
 			skip:
-			for (x++; x <= x2 && !(out[y*width+x] != 0 && labels[y*width+x]==0); x++);
+			
+			for (x++; x <= x2 && !(out[y*width+x] != 0 && labels[y*width+x]==oldvalue); x++);
+			
 			l = x;
 		} while (x <= x2);
 	}
@@ -335,7 +352,7 @@ static int iflood(int x, int y,       /* seed point */
 int alg_labeling (struct context *cnt)
 {
 	struct images *imgs=&cnt->imgs;
-	char *out=imgs->out;
+	unsigned char *out=imgs->out;
 	int *labels=imgs->labels;
 	int ix, iy, pixelpos;
 	int width=imgs->width;
@@ -344,6 +361,9 @@ int alg_labeling (struct context *cnt)
 	int current_label=2;
 	imgs->total_labels=0;
 	imgs->labelsize_max=0;
+	/* ALL labels above threshold are counted as labelgroup */
+	imgs->labelgroup_max=0;
+	imgs->labels_above=0;
 
 	/* init: 0 means no label set / not checked */
 	memset(labels, 0, width*height*sizeof(int));
@@ -355,16 +375,26 @@ int alg_labeling (struct context *cnt)
 				labels[pixelpos]=1;
 				continue;
 			}
+			
 			/* already visited by iflood */
 			if (labels[pixelpos] > 0)
 				continue;
-			labelsize=iflood(ix, iy, width, height, out, labels, current_label);
+			labelsize=iflood(ix, iy, width, height, out, labels, current_label, 0);
+			
 			if( labelsize > 0 ) {
 				//printf( "Label: %i (%i) Size: %i (%i,%i)\n", current_label, imgs->total_labels, labelsize, ix, iy );
+				/* Label above threshold? Mark it again (add 32768 to labelnumber) */
+				if (labelsize > cnt->threshold){
+					labelsize=iflood(ix, iy, width, height, out, labels, current_label+32768, current_label);
+					imgs->labelgroup_max+=labelsize;
+					imgs->labels_above++;
+				}
+				
 				if( imgs->labelsize_max < labelsize ){
 					imgs->labelsize_max=labelsize;
 					imgs->largest_label=current_label;
 				}
+				
 				imgs->total_labels++;
 				current_label++;
 			}
@@ -372,11 +402,12 @@ int alg_labeling (struct context *cnt)
 		pixelpos++; /* compensate for ix<width-1 */
 	}	
 	//printf( "%i Labels found. Largest connected Area: %i Pixel(s). Largest Label: %i\n", imgs->total_labels, imgs->labelsize_max, imgs->largest_label);
-	return imgs->labelsize_max;
+	/* return group of significant labels */
+	return imgs->labelgroup_max;
 }
 
 /* Dilates a 3x3 box */
-static int dilate9(char *img, int width, int height, void *buffer)
+static int dilate9(unsigned char *img, int width, int height, void *buffer)
 {
 	/* - row1, row2 and row3 represent lines in the temporary buffer 
 	 * - window is a sliding window containing max values of the columns
@@ -457,7 +488,7 @@ static int dilate9(char *img, int width, int height, void *buffer)
 }
 
 /* Dilates a + shape */
-static int dilate5(char *img, int width, int height, void *buffer)
+static int dilate5(unsigned char *img, int width, int height, void *buffer)
 {
 	/* - row1, row2 and row3 represent lines in the temporary buffer 
 	 * - mem holds the max value of the overlapping part of two + shapes
@@ -495,11 +526,11 @@ static int dilate5(char *img, int width, int height, void *buffer)
 		mem = MAX2(row2[0], row2[1]);
 		blob = 1; /* dummy value, must be > 0 */
 		
-		for(i = 1; i < width - 1; i++) {
+		for (i = 1; i < width - 1; i++) {
 			/* Get the max value of the "right edge" of the + shape. */
 			latest = MAX3(row1[i], row2[i + 1], row3[i]);
 			
-			if(blob == 0) {
+			if (blob == 0) {
 				/* In case the last blob is zero, only latest matters. */
 				blob = latest;
 				mem = row2[i + 1];
@@ -524,7 +555,7 @@ static int dilate5(char *img, int width, int height, void *buffer)
 }
 
 /* Erodes a 3x3 box */
-static int erode9(char *img, int width, int height, void *buffer, unsigned char flag)
+static int erode9(unsigned char *img, int width, int height, void *buffer, unsigned char flag)
 {
 	int y, i, sum = 0;
 	char *Row1,*Row2,*Row3;
@@ -561,7 +592,7 @@ static int erode9(char *img, int width, int height, void *buffer, unsigned char
 }
 
 /* Erodes in a + shape */
-static int erode5(char *img, int width, int height, void *buffer, unsigned char flag)
+static int erode5(unsigned char *img, int width, int height, void *buffer, unsigned char flag)
 {
 	int y, i, sum = 0;
 	char *Row1,*Row2,*Row3;
@@ -593,14 +624,13 @@ static int erode5(char *img, int width, int height, void *buffer, unsigned char
 	return sum;
 }
 
-
 /* 
  * Despeckling routine to remove noisy detections.
  */
 int alg_despeckle(struct context *cnt, int olddiffs)
 {
 	int diffs = 0;
-	char *out = cnt->imgs.out;
+	unsigned char *out = cnt->imgs.out;
 	int width = cnt->imgs.width;
 	int height= cnt->imgs.height;
 	int done = 0, i, len = strlen(cnt->conf.despeckle);
@@ -639,7 +669,7 @@ int alg_despeckle(struct context *cnt, int olddiffs)
 }
 
 /* Generate actual smartmask. Calculate sensitivity based on motion */
-void tune_smartmask (struct context *cnt)
+void alg_tune_smartmask(struct context *cnt)
 {
 	int i, diff;
 	
@@ -909,7 +939,7 @@ int alg_diff_standard (struct context *cnt, unsigned char *new)
 	 */
 
 	for (; i>0; i--) {
-		unsigned register char curdiff=(int)(abs(*ref-*new)); /* using a temp variable is 12% faster */
+		register unsigned char curdiff=(int)(abs(*ref-*new)); /* using a temp variable is 12% faster */
 		/* apply fixed mask */
 		if (mask)
 			curdiff=((int)(curdiff**mask++)/255);
@@ -958,7 +988,7 @@ char alg_diff_fast (struct context *cnt, int max_n_changes, unsigned char *new)
 
 	i=imgs->motionsize;
 	for (; i>0; i-=step) {
-		unsigned register char curdiff=(int)(abs((char)(*ref-*new))); /* using a temp variable is 12% faster */
+		register unsigned char curdiff=(int)(abs((char)(*ref-*new))); /* using a temp variable is 12% faster */
 		if (curdiff >  noise) {
 			diffs++;
 			if (diffs > max_n_changes)
@@ -1004,10 +1034,10 @@ int alg_lightswitch (struct context *cnt, int diffs)
 	return 0;
 }
 
-int alg_switchfilter (struct context *cnt, int diffs, struct coord *cent, char *newimg)
+int alg_switchfilter (struct context *cnt, int diffs, struct coord *cent, unsigned char *newimg)
 {
-	int linediff=diffs/cnt->imgs.height;
-	char *out=cnt->imgs.out;
+	int linediff = diffs / cnt->imgs.height;
+	unsigned char *out = cnt->imgs.out;
 	int y, x, line;
 	int lines=0, vertlines=0;
 
@@ -1031,7 +1061,7 @@ int alg_switchfilter (struct context *cnt, int diffs, struct coord *cent, char *
 		if (cnt->conf.text_changes) {
 			char tmp[80];
 			sprintf(tmp, "%d %d", lines, vertlines);
-			draw_text(newimg, cnt->imgs.width-10, 20, cnt->imgs.height, cnt->imgs.width, tmp);
+			draw_text(newimg, cnt->imgs.width-10, 20, cnt->imgs.width, cnt->imgs.height, tmp, cnt->conf.text_double);
 		}
 		return diffs;
 	}
