@@ -32,14 +32,14 @@ struct segment {
 };
 
 struct coord alg_locate_center_size(struct images *, int width, int height);
-void alg_draw_location(struct coord *, struct images *, int width, int height, char *, int);
+void alg_draw_location(struct coord *, struct images *, int width, int height, unsigned char *, int);
 int alg_diff(struct context *, unsigned char *);
 int alg_diff_standard(struct context *, unsigned char *);
 int alg_lightswitch(struct context *, int diffs);
-int alg_switchfilter(struct context *, int, struct coord *, char *);
+int alg_switchfilter(struct context *, int, struct coord *, unsigned char *);
 void alg_noise_tune(struct context *, unsigned char *);
 void alg_threshold_tune(struct context *, int, int);
 int alg_despeckle(struct context *, int);
-void tune_smartmask(struct context *);
+void alg_tune_smartmask(struct context *);
 
 #endif /* _INCLUDE_ALG_H */
