@@ -64,10 +64,10 @@ struct config conf_template = {
 	low_cpu:               0,
 	nochild:               0,
 	autobright:            0,
-	brightness:	       0,
-	contrast:	       0,
-	saturation:	       0,
-	hue:		       0,
+	brightness:            0,
+	contrast:              0,
+	saturation:            0,
+	hue:                   0,
 	roundrobin_frames:     1,
 	roundrobin_skip:       1,
 	pre_capture:           0,
@@ -87,12 +87,12 @@ struct config conf_template = {
 	control_port:          0,
 	control_localhost:     1,
 	control_html_output:   1,
-	control_authentication:NULL,	
+	control_authentication:NULL,
 	frequency:             0,
 	tuner_number:          0,
 	timelapse:             0,
 	timelapse_mode:        DEF_TIMELAPSE_MODE,
-#ifdef __freebsd__
+#ifdef  __freebsd__
 	tuner_device:          TUNER_DEVICE,
 #endif
 	video_device:          VIDEO_DEVICE,
@@ -121,6 +121,7 @@ struct config conf_template = {
 	motionvidpipe:         NULL,
 	netcam_url:            NULL,
 	netcam_userpass:       NULL,
+	netcam_proxy:          NULL,
 	pgsql_db:              NULL,
 	pgsql_host:            NULL,
 	pgsql_user:            NULL,
@@ -129,6 +130,7 @@ struct config conf_template = {
 	text_changes:          0,
 	text_left:             NULL,
 	text_right:            DEF_TIMESTAMP,
+	text_double:           0,
 	despeckle:             NULL,
 	minimum_motion_frames: 1,
 	// debug_parameter:       0
@@ -138,7 +140,6 @@ struct config conf_template = {
 
 static struct context **copy_bool(struct context **, char *, int);
 static struct context **copy_int(struct context **, char *, int);
-//struct context **copy_string(struct context **, char *, int);
 static struct context **config_thread(struct context **cnt, char *str, int val);
 
 static char *print_bool(struct context **, char **, int, int);
@@ -266,6 +267,15 @@ config_param config_params[] = {
 	print_string
 	},
 	{
+	"netcam_proxy",
+	"# URL to use for a netcam proxy server, if required, e.g. \"http://myproxy\".\n"
+	"# If a port number other than 80 is needed, use \"http://myproxy:1234\".\n"
+	"# Default: not defined",
+	CONF_OFFSET(netcam_proxy),
+	copy_string,
+	print_string
+	},
+	{
 	"auto_brightness",
 	"# Let motion regulate the brightness of a video device (default: off).\n"
 	"# The auto_brightness feature uses the brightness option as its target value.\n"
@@ -332,7 +342,7 @@ config_param config_params[] = {
 	"# Try to filter out noise generated by roundrobin (default: 0)",
 	CONF_OFFSET(switchfilter),
 	copy_bool,
-	print_int
+	print_bool
 	},
 
 	{
@@ -413,7 +423,7 @@ config_param config_params[] = {
 	"minimum_motion_frames",
 	"# Picture frames must contain motion at least the specified number of frames\n"
 	"# in a row before they are detected as true motion. At the default of 1, all\n"
-	"# motion is detected. Valid range: 1 to thousands, recommended 1-10",
+	"# motion is detected. Valid range: 1 to thousands, recommended 1-5",
 	CONF_OFFSET(minimum_motion_frames),
 	copy_int,
 	print_int
@@ -421,7 +431,10 @@ config_param config_params[] = {
 	{
 	"pre_capture",
 	"# Specifies the number of pre-captured (buffered) pictures from before motion\n"
-	"# was detected that will be output at motion detection (default: 0)",
+	"# was detected that will be output at motion detection.\n"
+	"# Recommended range: 0 to 5 (default: 0)\n"
+	"# Do not use large values! Large values will cause Motion to skip video frames and\n"
+	"# cause unsmooth mpegs. To smooth mpegs use larger values of post_capture instead.",
 	CONF_OFFSET(pre_capture),
 	copy_int,
 	print_int
@@ -638,6 +651,13 @@ config_param config_params[] = {
 	copy_bool,
 	print_bool
 	},
+	{
+	"text_double",
+	"# Draw characters at twice normal size on images. (default: off)",
+	CONF_OFFSET(text_double),
+	copy_bool,
+	print_bool
+	},
 
 	{
 	"target_dir",
@@ -729,7 +749,8 @@ config_param config_params[] = {
 	},
 	{
 	"webcam_motion",
-	"# Only output frames if motion is detected (default: off)",
+	"# Output frames at 1 fps when no motion is detected and increase to the\n"
+	"# rate given by webcam_maxrate when motion is detected (default: off)",
 	CONF_OFFSET(webcam_motion),
 	copy_bool,
 	print_bool
@@ -1083,7 +1104,7 @@ static void conf_cmdline (struct context *cnt, int thread)
 	 * if necessary. This is accomplished by calling mystrcpy();
 	 * see this function for more information.
 	 */
-	while ((c=getopt(conf->argc, conf->argv, "c:hns?"))!=EOF)
+	while ((c=getopt(conf->argc, conf->argv, "c:d:hns?"))!=EOF)
 		switch (c) {
 			case 'c':
 				if (thread==-1) strcpy(cnt->conf_filename, optarg);
@@ -1094,6 +1115,10 @@ static void conf_cmdline (struct context *cnt, int thread)
 			case 's':
 				conf->setup_mode=1;
 				break;
+			case 'd':
+				/* no validation - just take what user gives */
+				debug_level = atoi(optarg);
+				break;
 			case 'h':
 			case '?':
 			default:
@@ -1113,7 +1138,6 @@ static void conf_cmdline (struct context *cnt, int thread)
 struct context **conf_cmdparse(struct context **cnt, char *cmd, char *arg1)
 {
 	int i = 0;
-	const char msg[]="Unknown config option: ";
 
 	if(!cmd)
 		return cnt;
@@ -1143,8 +1167,7 @@ struct context **conf_cmdparse(struct context **cnt, char *cmd, char *arg1)
 	}
 
 	/* We reached the end of config_params without finding a matching option */
-	printf("%s\"%s\"\n", msg, cmd );
-	syslog(LOG_ERR, "%s\"%s\"", msg, cmd );
+	motion_log(cnt[0], LOG_ERR, 1, "Unknown config option \"%s\"",cmd);
 
 	return cnt;
 }
@@ -1234,10 +1257,8 @@ void conf_print(struct context **cnt)
 	FILE *conffile;
 
 	for (thread=0; cnt[thread]; thread++) {
-		const char msg[]="Writing config file to: ";
-		printf("[%d] %s%s\n", thread, msg, cnt[thread]->conf_filename);
-		syslog(LOG_INFO, "[%d] %s%s", thread, msg, cnt[thread]->conf_filename);
-		conffile=myfopen(cnt[thread]->conf_filename, "w");
+		motion_log(cnt[0], LOG_INFO, 1, "Writing config file to %s",cnt[thread]->conf_filename);
+		conffile=myfopen(cnt[0] ,cnt[thread]->conf_filename, "w");
 		if (!conffile)
 			continue;
 		fprintf(conffile, "# %s\n", cnt[thread]->conf_filename);
@@ -1340,28 +1361,25 @@ struct context ** conf_load (struct context **cnt)
 	}
 	if (!fp){      /* Commandline didn't work, try current dir */
 		if (cnt[0]->conf_filename[0])
-			printf("Configfile %s not found - trying defaults.\n", filename);
+			motion_log(cnt[0], -1, 1, "Configfile %s not found - trying defaults.", filename);
 		sprintf(filename, "motion.conf");
 		fp = fopen (filename, "r");
 	}
-	if (!fp) {	/* specified file does not exist... try default file */
+	if (!fp) {     /* specified file does not exist... try default file */
 		sprintf(filename, "%s/.motion/motion.conf", getenv("HOME"));
 		fp = fopen (filename, "r");
 		if (!fp) {
 			sprintf(filename, "%s/motion.conf", sysconfdir);
 			fp = fopen (filename, "r");
-			if (!fp) {	/* there is no config file.... use defaults */
-				printf("could not open configfile %s: %m\n", filename);
-			}
+			if (!fp)        /* there is no config file.... use defaults */
+				motion_log(cnt[0], -1, 1, "could not open configfile %s",filename);
 		}
 	}
 
 	/* Now we process the motion.conf config file and close it*/
 	if (fp) {
-		const char msg[]="Processing thread 0 - config file ";
 		strcpy(cnt[0]->conf_filename, filename);
-		printf("%s%s\n", msg, filename);
-		syslog(LOG_INFO, "%s%s", msg, filename);
+		motion_log(cnt[0], LOG_INFO, 0, "Processing thread 0 - config file %s",filename);
 		cnt=conf_process(cnt, fp);
 		fclose(fp);
 	}
@@ -1398,10 +1416,6 @@ void malloc_strings (struct context * cnt)
 		if (config_params[i].copy == copy_string) { /* if member is a string */
 			/* val is made to point to a pointer to the current string */
 			val=(void *)cnt+config_params[i].conf_value;
-			
-			/*printf("config_params[i].param_name is string: %s\n",config_params[i].param_name);
-			printf("string value: %s\n",*(char **)val);
-			printf("string address: %p\n",*(char **)val);*/
 
 			/* if there is a string, malloc() space for it, copy
 			 * the string to new space, and point to the new
@@ -1450,10 +1464,7 @@ static struct context **copy_bool (struct context **cnt, char *str, int val_ptr)
 	i=-1;
 	while(cnt[++i]) {
 		tmp=(void *)cnt[i]+(int)val_ptr;
-		if ( !strcmp(str, "1") ||
-		     !strcasecmp(str, "yes") ||
-		     !strcasecmp(str,"on"))
-		{
+		if ( !strcmp(str, "1") || !strcasecmp(str, "yes") || !strcasecmp(str,"on")) {
 			*((int *)tmp) = 1;
 		} else {
 			*((int *)tmp) = 0;
@@ -1559,7 +1570,7 @@ char *mystrdup(char *from)
 	} else {
 		stringlength = strlen(from);
 		stringlength = (stringlength < PATH_MAX ? stringlength : PATH_MAX);
-		tmp = (char *)mymalloc(stringlength + 1);
+		tmp = (char *)mymalloc(NULL, stringlength + 1);
 		strncpy(tmp, from, stringlength);
 
 		/* We must ensure the string always has a NULL terminator.
@@ -1635,7 +1646,7 @@ static char *print_int(struct context **cnt, char **str, int parm, int threadnr)
 
 static char *print_thread(struct context **cnt, char **str, int parm, int threadnr)
 {
-	char *retval=mymalloc(1);
+	char *retval=mymalloc(cnt[0], 1);
 	int i=0;
 
 	if (!str || threadnr || !retval)
@@ -1643,7 +1654,7 @@ static char *print_thread(struct context **cnt, char **str, int parm, int thread
 
 	retval[0]=0;
 	while (cnt[++i]) {
-		retval=myrealloc(retval, strlen(retval)+strlen(cnt[i]->conf_filename)+10, "print_thread");
+		retval=myrealloc(cnt[0] ,retval, strlen(retval)+strlen(cnt[i]->conf_filename)+10, "print_thread");
 		sprintf(retval+strlen(retval), "thread %s\n", cnt[i]->conf_filename);
 	}
 	*str=retval;
@@ -1671,10 +1682,7 @@ static struct context **config_thread(struct context **cnt, char *str, int val)
 
 	fp=fopen(str, "r");
 	if (!fp) {
-		const char msg1[]="Thread config file ";
-		const char msg2[]=" not found: ";
-		printf("%s%s%s%m\n", msg1, str, msg2);
-		syslog(LOG_ERR, "%s%s%s%m", msg1, str, msg2);
+		motion_log(cnt[0], LOG_ERR, 1, "Thread config file %s not found",str);
 		return cnt;
 	}
 
@@ -1687,10 +1695,10 @@ static struct context **config_thread(struct context **cnt, char *str, int val)
 	 * First thread is 0 so the number of threads is i+1
 	 * plus an extra for the NULL pointer. This gives i+2
 	 */
-	cnt=myrealloc(cnt, sizeof(struct context *)*(i+2), "config_thread");
+	cnt=myrealloc(cnt[0], cnt, sizeof(struct context *)*(i+2), "config_thread");
 
 	/* Now malloc space for an additional context structure for thread nr. i */
-	cnt[i]=mymalloc(sizeof(struct context));
+	cnt[i]=mymalloc(cnt[0], sizeof(struct context));
 	
 	/* And make this an exact clone of the context structure for thread 0 */
 	memcpy(cnt[i], cnt[0], sizeof(struct context));
@@ -1702,23 +1710,18 @@ static struct context **config_thread(struct context **cnt, char *str, int val)
 	 * malloc_strings takes care of this.
 	 */
 	malloc_strings(cnt[i]);
-	
+
+#if 0		/* we will assign threadnr when we launch the threads */
 	/* Set the current thread number */
 	cnt[i]->threadnr=i;
+#endif
 	
 	/* Mark the end if the array of pointers to context structures */
 	cnt[i+1]=NULL;
 
 	/* process the thread's config file and notify user on console */
 	strcpy(cnt[i]->conf_filename, str);
-	
-	{
-		const char msg1[]="Processing thread ";
-		const char msg2[]=" - config file ";
-		printf("%s%d%s%s\n", msg1, i, msg2, str);
-		syslog(LOG_INFO, "%s%d%s%s\n", msg1, i, msg2, str);
-	}
-	
+	motion_log(cnt[0], LOG_INFO, 0, "Processing config file %s", str);
 	conf_process(cnt+i, fp);
 	
 	/* Finally we close the thread config file */
@@ -1727,7 +1730,7 @@ static struct context **config_thread(struct context **cnt, char *str, int val)
 	return cnt;
 }
 
-static void usage (void)
+static void usage ()
 {
 	printf("motion Version "VERSION", Copyright 2000 Jeroen Vreeken\n");
 	printf("\nusage:\tmotion [options]\n");
@@ -1736,9 +1739,11 @@ static void usage (void)
 	printf("-n\t\tRun in non-daemon mode.\n");
 	printf("-s\t\tRun in setup mode.\n");
 	printf("-c config\tFull path and filename of config file.\n");
+	printf("-d \t\tDebug mode.\n");
 	printf("-h\t\tShow this screen.\n");
 	printf("\n");
 	printf("Motion is configured using a config file only. If none is supplied,\n");
 	printf("it will read motion.conf from current directory, ~/.motion or %s.\n", sysconfdir);
 	printf("\n");
+	
 }
