@@ -34,7 +34,7 @@
 static void exec_command(struct context *cnt, char *command, char *arg)
 {
 	char stamp[PATH_MAX];
-	mystrftime(stamp, sizeof(stamp), command, cnt->currenttime, cnt);
+	mystrftime(cnt ,stamp, sizeof(stamp), command, cnt->currenttime);
 	if (arg) {
 		strcat(stamp, " ");
 		strcat(stamp, arg);
@@ -50,37 +50,36 @@ static void exec_command(struct context *cnt, char *command, char *arg)
 		for (i=getdtablesize(); i>2; --i)
 			close(i);
 		
-		execl("/bin/sh", "sh", "-c", stamp, " &", 0);
-		
-		{
-			const char msg1[]="Unable to start external command ";
-			const char msg2[]=" with parameters ";
-			printf("[%d] %s'%s'%s'%s': %m\n", cnt->threadnr, msg1, stamp, msg2, arg);
-			syslog(LOG_ERR, "[%d] %s'%s'%s'%s': %m", cnt->threadnr, msg1, stamp, msg2, arg);
-		}
-		
+		execl("/bin/sh", "sh", "-c", stamp, " &", NULL);
+
+		/* if above function succeeds the program never reach here */
+		motion_log(cnt, LOG_ERR, 1, "Unable to start external command '%s' with parameters '%s'",stamp,arg);
+
 		exit(1);
 	}
 	else if (cnt->conf.setup_mode)
-		printf("[%d] Executing external command '%s'\n", cnt->threadnr, stamp);
+		motion_log(cnt, -1, 0, "Executing external command '%s'", stamp);
 }
 
 /* 
  *	Event handlers
  */
 
-static void event_newfile(int type, struct context *cnt, char *filename, void *ftype, struct tm *tm)
+static void event_newfile(struct context *cnt, int type, unsigned char *dummy,
+                          char *filename, void *ftype, struct tm *tm)
 {
-	printf("[%d] File of type %ld saved to: %s\n", cnt->threadnr, (unsigned long)ftype, filename);
+	motion_log(cnt, -1, 0, "File of type %ld saved to: %s", (unsigned long)ftype, filename);
 }
 
-static void event_motion(int type, struct context *cnt, char *filename, void *ftype, struct tm *tm)
+static void event_motion(struct context *cnt, int type, unsigned char *dummy,
+                         char *filename, void *ftype, struct tm *tm)
 {
 	if (!cnt->conf.quiet)
 		printf("\a");
 }
 
-static void on_picture_save_command(int type, struct context *cnt, char *filename, void *arg, struct tm *tm)
+static void on_picture_save_command(struct context *cnt, int type, unsigned char *dummy,
+                                    char *filename, void *arg, struct tm *tm)
 {
 	int ftype = (unsigned long)arg;	
 
@@ -91,7 +90,8 @@ static void on_picture_save_command(int type, struct context *cnt, char *filenam
 		exec_command(cnt, cnt->conf.on_movie_start, filename);
 }
 
-static void on_motion_detected_command(int type, struct context *cnt, char *dummy, void *dummy2, struct tm *tm)
+static void on_motion_detected_command(struct context *cnt, int type, unsigned char *dummy1,
+                                       char *dummy2, void *dummy3, struct tm *tm)
 {
 	if (cnt->conf.on_motion_detected)
 		exec_command(cnt, cnt->conf.on_motion_detected, 0);
@@ -99,7 +99,8 @@ static void on_motion_detected_command(int type, struct context *cnt, char *dumm
 
 #if defined(HAVE_MYSQL) || defined(HAVE_PGSQL)
 
-static void event_sqlnewfile(int type, struct context *cnt, char *filename, void *arg, struct tm *tm)
+static void event_sqlnewfile(struct context *cnt, int type, unsigned char *dummy,
+                             char *filename, void *arg, struct tm *tm)
 {
 	int sqltype = (unsigned long)arg;
 
@@ -113,11 +114,12 @@ static void event_sqlnewfile(int type, struct context *cnt, char *filename, void
 	{
 		char sqlquery[512];
 		char timestr[20];
-		
+	
 		strftime(timestr, sizeof(timestr), "%Y-%m-%d %T", cnt->currenttime);
 	
 		sprintf(sqlquery,
-		    "insert into security(camera, filename, frame, file_type, time_stamp %s) values('%d', '%s', '%d', '%d', '%s' %s%s%s)",
+		    "insert into security(camera, filename, frame, file_type, "
+		    "time_stamp %s) values('%d', '%s', '%d', '%d', '%s' %s%s%s)",
 		    cnt->conf.text_left ? ", text_left" : "" ,
 		    cnt->threadnr, filename, cnt->shots, sqltype,  timestr,
 		    cnt->conf.text_left ? ", '" : "" ,
@@ -126,28 +128,20 @@ static void event_sqlnewfile(int type, struct context *cnt, char *filename, void
 		    );
 
 #ifdef HAVE_MYSQL
-		if (cnt->conf.mysql_db)
-		{
-			if (mysql_query(cnt->database, sqlquery) != 0) {
-				const char msg[]="Mysql query failed: ";
-				printf("[%d] %s%s\n", cnt->threadnr, msg, mysql_error(cnt->database));
-				syslog(LOG_ERR, "[%d] %s%s", cnt->threadnr, msg, mysql_error(cnt->database));
-			}
+		if (cnt->conf.mysql_db) {
+			if (mysql_query(cnt->database, sqlquery) != 0)
+				motion_log(cnt, LOG_ERR, 1, "Mysql query failed");
 		}
 #endif /* HAVE_MYSQL */
 
 #ifdef HAVE_PGSQL
-		if (cnt->conf.pgsql_db)
-		{
+		if (cnt->conf.pgsql_db) {
 			PGresult *res;
 
 			res = PQexec(cnt->database_pg, sqlquery);
 
-			if (PQresultStatus(res) != PGRES_COMMAND_OK)
-			{
-				const char msg[]="PGSQL query failed: ";
-				printf("[%d] %s%s\n", cnt->threadnr, msg, PQerrorMessage(cnt->database_pg));
-				syslog(LOG_ERR, "[%d] %s%s", cnt->threadnr, msg, PQerrorMessage(cnt->database_pg));
+			if (PQresultStatus(res) != PGRES_COMMAND_OK) {
+				motion_log(cnt, LOG_ERR, 1, "PGSQL query failed");
 				PQclear(res);
 			}
 		}
@@ -159,45 +153,44 @@ static void event_sqlnewfile(int type, struct context *cnt, char *filename, void
 #endif /* defined HAVE_MYSQL || defined HAVE_PGSQL */
 
 
-static void event_firstmotion(int type, struct context *cnt, char *dummy, void *dummy2, struct tm *tm)
+static void event_firstmotion(struct context *cnt, int type, unsigned char *dummy1,
+                              char *dummy2, void *dummy3, struct tm *tm)
 {
 	if (cnt->conf.on_event_start)
 		exec_command(cnt, cnt->conf.on_event_start, 0);
 }
 
-static void on_event_end_command(int type, struct context *cnt, char *dummy, void *dummy2, struct tm *tm)
+static void on_event_end_command(struct context *cnt, int type, unsigned char *dummy1,
+                                 char *dummy2, void *dummy3, struct tm *tm)
 {
 	if (cnt->conf.on_event_end)
 		exec_command(cnt, cnt->conf.on_event_end, 0);
 }
 
-static void event_stop_webcam(int type, struct context *cnt, char *dmy, void *dmy2, struct tm *tm)
+static void event_stop_webcam(struct context *cnt, int type, unsigned char *dummy1,
+                              char *dummy2, void *dummy3, struct tm *tm)
 {
 	if (cnt->conf.webcam_port){
 		webcam_stop(cnt);
 	}
 }
 
-static void event_webcam_put(int type, struct context *cnt, char *img, void *devpipe, struct tm *tm)
+static void event_webcam_put(struct context *cnt, int type, unsigned char *img,
+                             char *dummy1, void *dummy2, struct tm *tm)
 {
 	if (cnt->conf.webcam_port) {
-		if (type==EVENT_IMAGE_DETECTED && cnt->conf.webcam_motion)
-			webcam_put(cnt, img);
-		if (type==EVENT_IMAGE && !cnt->conf.webcam_motion)
-			webcam_put(cnt, img);
+		webcam_put(cnt, img);
 	}
 }
 
 #ifndef WITHOUT_V4L
 #ifndef __freebsd__
-static void event_vid_putpipe(int type, struct context *cnt, char *img, void *devpipe, struct tm *tm)
+static void event_vid_putpipe(struct context *cnt, int type, unsigned char *img,
+                              char *dummy, void *devpipe, struct tm *tm)
 {
 	if (*(int *)devpipe >= 0) {
-		if (vid_putpipe(*(int *)devpipe, img, cnt->imgs.size) == -1) {
-			const char msg[]="Failed to put image into video pipe.";
-			printf("[%d] %s\n", cnt->threadnr, msg);
-			syslog(LOG_ERR, "[%d] %s", cnt->threadnr, msg);
-		}
+		if (vid_putpipe(*(int *)devpipe, img, cnt->imgs.size) == -1)
+			motion_log(cnt, LOG_ERR, 1, "Failed to put image into video pipe");
 	}
 }
 #endif /* __freebsd__ */
@@ -211,7 +204,8 @@ char *imageext(struct context *cnt)
 	return "jpg";
 }
 
-static void event_image_detect(int type, struct context *cnt, char *newimg, void *dummy2, struct tm *currenttime)
+static void event_image_detect(struct context *cnt, int type, unsigned char *newimg,
+                               char *dummy1, void *dummy2, struct tm *currenttime)
 {
 	struct config *conf=&cnt->conf;
 	char fullfilename[PATH_MAX];
@@ -229,7 +223,7 @@ static void event_image_detect(int type, struct context *cnt, char *newimg, void
 		else
 			jpegpath = DEF_JPEGPATH;
 			
-		mystrftime(filename, sizeof(filename), jpegpath, currenttime, cnt);
+		mystrftime(cnt, filename, sizeof(filename), jpegpath, currenttime);
 		/* motion images gets same name as normal images plus an appended 'm' */
 		sprintf(filenamem, "%sm", filename);
 		sprintf(fullfilename, "%s/%s.%s", cnt->conf.filepath, filename, imageext(cnt));
@@ -243,7 +237,8 @@ static void event_image_detect(int type, struct context *cnt, char *newimg, void
 	}
 }
 
-static void event_image_snapshot(int type, struct context *cnt, char *img, void *dummy2, struct tm *currenttime)
+static void event_image_snapshot(struct context *cnt, int type, unsigned char *img,
+                                 char *dummy1, void *dummy2, struct tm *currenttime)
 {
 	char fullfilename[PATH_MAX];
 
@@ -259,7 +254,7 @@ static void event_image_snapshot(int type, struct context *cnt, char *img, void
 		else
 			snappath = DEF_SNAPPATH;
 			
-		mystrftime(filepath, sizeof(filepath), snappath, currenttime, cnt);
+		mystrftime(cnt, filepath, sizeof(filepath), snappath, currenttime);
 		sprintf(filename, "%s.%s", filepath, imageext(cnt));
 		sprintf(fullfilename, "%s/%s", cnt->conf.filepath, filename);
 		put_picture(cnt, fullfilename, img, FTYPE_IMAGE_SNAPSHOT);
@@ -268,7 +263,10 @@ static void event_image_snapshot(int type, struct context *cnt, char *img, void
 		   the link always points to a valid file. */
 		sprintf(linkpath, "%s/lastsnap.%s", cnt->conf.filepath, imageext(cnt));
 		remove(linkpath);
-		symlink(filename, linkpath);
+		if (symlink(filename, linkpath)) {
+			motion_log(cnt, LOG_ERR, 1, "Could not create symbolic link [%s]",filename);
+			return;
+		}
 	} else {
 		sprintf(fullfilename, "%s/lastsnap.%s", cnt->conf.filepath, imageext(cnt));
 		remove(fullfilename);
@@ -285,7 +283,8 @@ static void grey2yuv420p(unsigned char *u, unsigned char *v, int width, int heig
 	memset(v, 128, width*height/4);
 }
 
-static void on_movie_end_command(int type, struct context *cnt, char *filename, void *arg, struct tm *tm)
+static void on_movie_end_command(struct context *cnt, int type, unsigned char *dummy,
+                                 char *filename, void *arg, struct tm *tm)
 {
 	int ftype = (unsigned long) arg;
 
@@ -293,7 +292,8 @@ static void on_movie_end_command(int type, struct context *cnt, char *filename,
 		exec_command(cnt, cnt->conf.on_movie_end, filename);
 }
 
-static void event_ffmpeg_newfile(int type, struct context *cnt, char *img, void *dummy2, struct tm *currenttime)
+static void event_ffmpeg_newfile(struct context *cnt, int type, unsigned char *img,
+                                 char *dummy1, void *dummy2, struct tm *currenttime)
 {
 	int width=cnt->imgs.width;
 	int height=cnt->imgs.height;
@@ -311,14 +311,14 @@ static void event_ffmpeg_newfile(int type, struct context *cnt, char *img, void
 		mpegpath = cnt->conf.mpegpath;
 	else
 		mpegpath = DEF_MPEGPATH;
-	mystrftime(stamp, sizeof(stamp), mpegpath, currenttime, cnt);
+	mystrftime(cnt, stamp, sizeof(stamp), mpegpath, currenttime);
 	/* motion mpegs get the same name as normal mpegs plus an appended 'm' */
 	sprintf(cnt->motionfilename, "%s/%sm", cnt->conf.filepath, stamp);
 	sprintf(cnt->newfilename, "%s/%s", cnt->conf.filepath, stamp);
 
 	if (cnt->conf.ffmpeg_cap_new) {
 		if (cnt->imgs.type==VIDEO_PALETTE_GREY) {
-			convbuf=mymalloc((width*height)/2);
+			convbuf=mymalloc(cnt, (width*height)/2);
 			y=img;
 			u=convbuf;
 			v=convbuf+(width*height)/4;
@@ -337,19 +337,20 @@ static void event_ffmpeg_newfile(int type, struct context *cnt, char *img, void
 			fps=30;
 		if (fps<2)
 			fps=2;
-		if ( (cnt->ffmpeg_new=ffmpeg_open(cnt->conf.ffmpeg_video_codec, cnt->newfilename, y, u, v, cnt->imgs.width, cnt->imgs.height, fps, cnt->conf.ffmpeg_bps, cnt->conf.ffmpeg_vbr)) == NULL){
-			const char msg[]="ffopen_open error creating file ";
-			printf("[%d] %s[%s]\n", cnt->threadnr, msg, cnt->newfilename);
-			syslog(LOG_ERR,"[%d] %s[%s]", cnt->threadnr, msg, cnt->newfilename);
+		if ( (cnt->ffmpeg_new =
+		      ffmpeg_open(cnt, cnt->conf.ffmpeg_video_codec, cnt->newfilename, y, u, v,
+		                  cnt->imgs.width, cnt->imgs.height, fps, cnt->conf.ffmpeg_bps,
+		                  cnt->conf.ffmpeg_vbr)) == NULL) {
+			motion_log(cnt, LOG_ERR, 1, "ffopen_open error creating file [%s]",cnt->newfilename);
 			cnt->finish=1;
 			return;
 		}
 		((struct ffmpeg *)cnt->ffmpeg_new)->udata=convbuf;
-		event(EVENT_FILECREATE, cnt, cnt->newfilename, (void *)FTYPE_MPEG, NULL);
+		event(cnt, EVENT_FILECREATE, NULL, cnt->newfilename, (void *)FTYPE_MPEG, NULL);
 	}
 	if (cnt->conf.ffmpeg_cap_motion) {
 		if (cnt->imgs.type==VIDEO_PALETTE_GREY) {
-			convbuf=mymalloc((width*height)/2);
+			convbuf=mymalloc(cnt, (width*height)/2);
 			y=cnt->imgs.out;
 			u=convbuf;
 			v=convbuf+(width*height)/4;
@@ -368,19 +369,21 @@ static void event_ffmpeg_newfile(int type, struct context *cnt, char *img, void
 			fps=30;
 		if (fps<2)
 			fps=2;
-		if ( (cnt->ffmpeg_motion=ffmpeg_open(cnt->conf.ffmpeg_video_codec, cnt->motionfilename, y, u, v, cnt->imgs.width, cnt->imgs.height, fps, cnt->conf.ffmpeg_bps, cnt->conf.ffmpeg_vbr)) == NULL){
-			const char msg[]="ffopen_open error creating file ";
-			printf("[%d] %s[%s]\n", cnt->threadnr, msg, cnt->motionfilename);
-			syslog(LOG_ERR,"[%d] %s[%s]", cnt->threadnr, msg, cnt->motionfilename);
+		if ( (cnt->ffmpeg_motion =
+		      ffmpeg_open(cnt ,cnt->conf.ffmpeg_video_codec, cnt->motionfilename, y, u, v,
+		                  cnt->imgs.width, cnt->imgs.height, fps, cnt->conf.ffmpeg_bps,
+		                  cnt->conf.ffmpeg_vbr)) == NULL){
+			motion_log(cnt, LOG_ERR, 1, "ffopen_open error creating file [%s]", cnt->motionfilename);
 			cnt->finish=1;
 			return;
 		}
 		cnt->ffmpeg_motion->udata=convbuf;
-		event(EVENT_FILECREATE, cnt, cnt->motionfilename, (void *)FTYPE_MPEG_MOTION, NULL);
+		event(cnt, EVENT_FILECREATE, NULL, cnt->motionfilename, (void *)FTYPE_MPEG_MOTION, NULL);
 	}
 }
 
-static void event_ffmpeg_timelapse(int type, struct context *cnt, char *img, void *dummy2, struct tm *currenttime)
+static void event_ffmpeg_timelapse(struct context *cnt, int type, unsigned char *img,
+                                   char *dummy1, void *dummy2, struct tm *currenttime)
 {
 	int width = cnt->imgs.width;
 	int height = cnt->imgs.height;
@@ -396,10 +399,10 @@ static void event_ffmpeg_timelapse(int type, struct context *cnt, char *img, voi
 		else
 			timepath = DEF_TIMEPATH;
 		
-		mystrftime(tmp, sizeof(tmp), timepath, currenttime, cnt);
+		mystrftime(cnt, tmp, sizeof(tmp), timepath, currenttime);
 		sprintf(cnt->timelapsefilename, "%s/%s", cnt->conf.filepath, tmp);
 		if (cnt->imgs.type == VIDEO_PALETTE_GREY) {
-			convbuf = mymalloc((width*height)/2);
+			convbuf = mymalloc(cnt, (width*height)/2);
 			y = img;
 			u = convbuf;
 			v = convbuf+(width*height)/4;
@@ -410,15 +413,16 @@ static void event_ffmpeg_timelapse(int type, struct context *cnt, char *img, voi
 			u = img+width*height;
 			v = u+(width*height)/4;
 		}
-		if ( (cnt->ffmpeg_timelapse = ffmpeg_open(TIMELAPSE_CODEC, cnt->timelapsefilename, y, u, v, cnt->imgs.width, cnt->imgs.height, 24, cnt->conf.ffmpeg_bps, cnt->conf.ffmpeg_vbr)) == NULL){
-			const char msg[]="ffopen_open error creating file ";
-			printf("[%d] %s[%s]\n", cnt->threadnr, msg, cnt->timelapsefilename);
-			syslog(LOG_ERR,"[%d] %s[%s]", cnt->threadnr, msg, cnt->timelapsefilename);
+		if ( (cnt->ffmpeg_timelapse =
+		      ffmpeg_open(cnt ,TIMELAPSE_CODEC, cnt->timelapsefilename, y, u, v,
+		                  cnt->imgs.width, cnt->imgs.height, 24, cnt->conf.ffmpeg_bps,
+		                  cnt->conf.ffmpeg_vbr)) == NULL) {
+			motion_log(cnt, LOG_ERR, 1, "ffopen_open error creating file [%s]", cnt->timelapsefilename);
 			cnt->finish=1;
 			return;
 		}
 		cnt->ffmpeg_timelapse->udata = convbuf;
-		event(EVENT_FILECREATE, cnt, cnt->timelapsefilename, (void *)FTYPE_MPEG_TIMELAPSE,NULL);
+		event(cnt, EVENT_FILECREATE, NULL, cnt->timelapsefilename, (void *)FTYPE_MPEG_TIMELAPSE, NULL);
 	}
 	
 	y = img;
@@ -429,11 +433,12 @@ static void event_ffmpeg_timelapse(int type, struct context *cnt, char *img, voi
 		u = img+width*height;
 	
 	v = u+(width*height)/4;
-	ffmpeg_put_other_image(cnt->ffmpeg_timelapse, y, u, v);		
+	ffmpeg_put_other_image(cnt ,cnt->ffmpeg_timelapse, y, u, v);
 	
 }
 
-static void event_ffmpeg_put(int type, struct context *cnt, char *img, void *dummy2, struct tm *tm)
+static void event_ffmpeg_put(struct context *cnt, int type, unsigned char *img,
+                             char *dummy1, void *dummy2, struct tm *tm)
 {
 	if (cnt->ffmpeg_new)
 	{
@@ -448,15 +453,16 @@ static void event_ffmpeg_put(int type, struct context *cnt, char *img, void *dum
 			u = y + (width * height);
 		
 		v = u + (width * height) / 4;
-		ffmpeg_put_other_image(cnt->ffmpeg_new, y, u, v);
+		ffmpeg_put_other_image(cnt, cnt->ffmpeg_new, y, u, v);
 	}
 	
 	if (cnt->ffmpeg_motion) {
-		ffmpeg_put_image(cnt->ffmpeg_motion);
+		ffmpeg_put_image(cnt, cnt->ffmpeg_motion);
 	}
 }
 
-static void event_ffmpeg_closefile(int type, struct context *cnt, char *dummy, void *dummy2, struct tm *tm)
+static void event_ffmpeg_closefile(struct context *cnt, int type, unsigned char *dummy1,
+                                   char *dummy2, void *dummy3, struct tm *tm)
 {
 	
 	if (cnt->ffmpeg_new) {
@@ -465,7 +471,7 @@ static void event_ffmpeg_closefile(int type, struct context *cnt, char *dummy, v
 		ffmpeg_close(cnt->ffmpeg_new);
 		cnt->ffmpeg_new=NULL;
 
-		event(EVENT_FILECLOSE, cnt, cnt->newfilename, (void *)FTYPE_MPEG, NULL);
+		event(cnt, EVENT_FILECLOSE, NULL, cnt->newfilename, (void *)FTYPE_MPEG, NULL);
 	}
 	if (cnt->ffmpeg_motion) {
 		if (cnt->ffmpeg_motion->udata)
@@ -473,11 +479,12 @@ static void event_ffmpeg_closefile(int type, struct context *cnt, char *dummy, v
 		ffmpeg_close(cnt->ffmpeg_motion);
 		cnt->ffmpeg_motion=NULL;
 
-		event(EVENT_FILECLOSE, cnt, cnt->motionfilename, (void *)FTYPE_MPEG_MOTION, NULL);
+		event(cnt, EVENT_FILECLOSE, NULL, cnt->motionfilename, (void *)FTYPE_MPEG_MOTION, NULL);
 	}
 }
 
-static void event_ffmpeg_timelapseend(int type, struct context *cnt, char *dummy, void *dummy2, struct tm *tm)
+static void event_ffmpeg_timelapseend(struct context *cnt, int type, unsigned char *dummy1,
+                                      char *dummy2, void *dummy3, struct tm *tm)
 {
 	if (cnt->ffmpeg_timelapse) {
 		if (cnt->ffmpeg_timelapse->udata)
@@ -485,7 +492,7 @@ static void event_ffmpeg_timelapseend(int type, struct context *cnt, char *dummy
 		ffmpeg_close(cnt->ffmpeg_timelapse);
 		cnt->ffmpeg_timelapse=NULL;
 
-		event(EVENT_FILECLOSE, cnt, cnt->timelapsefilename, (void *)FTYPE_MPEG_TIMELAPSE, NULL);
+		event(cnt, EVENT_FILECLOSE, NULL, cnt->timelapsefilename, (void *)FTYPE_MPEG_TIMELAPSE, NULL);
 	}
 }
 
@@ -549,7 +556,7 @@ struct event_handlers event_handlers[] = {
 #endif /* __freebsd__ */
 #endif /* WITHOUT_V4L */
 	{
-	EVENT_IMAGE | EVENT_IMAGE_DETECTED,
+	EVENT_WEBCAM,
 	event_webcam_put
 	},
 #ifdef HAVE_FFMPEG
@@ -585,12 +592,23 @@ struct event_handlers event_handlers[] = {
 	{0, NULL}
 };
 
-void event(int type, struct context *cnt, char *filename, void *eventdata, struct tm *tm)
+
+/* The event functions are defined with the following parameters:
+ * - Type as defined in event.h (EVENT_...)
+ * - The global context struct cnt
+ * - image - A pointer to unsigned char as used for images
+ * - filename - A pointer to typically a string for a file path
+ * - eventdata - A void pointer that can be cast to anything. E.g. FTYPE_...
+ * - tm - A tm struct that carries a full time structure
+ * The split between unsigned images and signed filenames was introduced in 3.2.2
+ * as a code reading friendly solution to avoid a stream of compiler warnings in gcc 4.0.
+ */
+void event(struct context *cnt, int type, unsigned char *image, char *filename, void *eventdata, struct tm *tm)
 {
 	int i=-1;
 
 	while (event_handlers[++i].handler) {
 		if (type & event_handlers[i].type)
-			event_handlers[i].handler(type, cnt, filename, eventdata, tm);
+			event_handlers[i].handler(cnt, type, image, filename, eventdata, tm);
 	}
 }
