@@ -20,31 +20,39 @@
  * non-standard framerates. Previous builds contained a broken hack 
  * that padded with B frames to obtain the correct framerate.
  */
-#define FFMPEG_NO_NONSTD_MPEG1
-
-#ifdef __GNUC__
+#	define FFMPEG_NO_NONSTD_MPEG1
+#	ifdef __GNUC__
 /* #warning is a non-standard gcc extension */
-#	warning **************************************************
-#	warning Your version of FFmpeg is newer than version 0.4.8
-#       warning Newer versions of ffmpeg do not support MPEG1 with
-#	warning non-standard framerate. MPEG1 will be disabled for
-#	warning normal video output. You can still use mpeg4 and
-#       warning and mpeg4ms which are both better in terms of size
-#       warning and quality. MPEG1 is always used for timelapse.
-#       warning Please read the Motion Guide for more information.
-#       warning Note that this is not an error message!
-#	warning **************************************************
-#endif
-
-#endif
+#		warning **************************************************
+#		warning Your version of FFmpeg is newer than version 0.4.8
+#		warning Newer versions of ffmpeg do not support MPEG1 with
+#		warning non-standard framerate. MPEG1 will be disabled for
+#		warning normal video output. You can still use mpeg4 and
+#		warning and mpeg4ms which are both better in terms of size
+#		warning and quality. MPEG1 is always used for timelapse.
+#		warning Please read the Motion Guide for more information.
+#		warning Note that this is not an error message!
+#		warning **************************************************
+#	endif /* __GNUC__ */
+#endif /* LIBAVCODEC_BUILD > 4680 */
 
 #if FFMPEG_VERSION_INT >= 0x000409
 /* The API for av_write_frame changed with FFmpeg version 0.4.9pre1.
  * It now uses an AVPacket struct instead of direct parameters to the
  * function.
  */
-#define FFMPEG_AVWRITEFRAME_NEWAPI
-#endif
+#	define FFMPEG_AVWRITEFRAME_NEWAPI
+#endif /* FFMPEG_VERSION_INT >= 0x000409 */
+
+#if LIBAVFORMAT_BUILD >= 4629
+/* In this build/header version, the codec member of struct AVStream
+ * was changed to a pointer so changes to AVCodecContext shouldn't
+ * break binary compatibility with AVStream.
+ */
+#	define AVSTREAM_CODEC_PTR(avs_ptr) (avs_ptr->codec)
+#else
+#	define AVSTREAM_CODEC_PTR(avs_ptr) (&avs_ptr->codec)
+#endif /* LIBAVFORMAT_BUILD >= 4629 */
 
 /* Name of custom file protocol for appending to existing files instead
  * of truncating.
@@ -52,13 +60,13 @@
 #define APPEND_PROTO "appfile"
 
 /* Some forward-declarations. */
-void ffmpeg_put_frame(struct ffmpeg *, AVFrame *);
+void ffmpeg_put_frame(struct context *, struct ffmpeg *, AVFrame *);
 void ffmpeg_cleanups(struct ffmpeg *);
-AVFrame *ffmpeg_prepare_frame(struct ffmpeg *, unsigned char *, unsigned char *, 
-	unsigned char *);
+AVFrame *ffmpeg_prepare_frame(struct context *, struct ffmpeg *, unsigned char *, 
+                              unsigned char *, unsigned char *);
 
 /* This is the trailer used to end mpeg1 videos. */
-static char mpeg1_trailer[] = {0x00, 0x00, 0x01, 0xb7};
+static unsigned char mpeg1_trailer[] = {0x00, 0x00, 0x01, 0xb7};
 
 /* Append version of the file open function used in libavformat when opening
  * an ordinary file. The original file open function truncates an existing
@@ -71,8 +79,9 @@ int file_open_append(URLContext *h, const char *filename, int flags)
 
 	/* Skip past the protocol part of filename. */
 	colon = strchr(filename, ':');
-	if (colon)
+	if (colon) {
 		filename = colon + 1;
+	}
 
 	if (flags & URL_RDWR) {
 		access = O_CREAT | O_APPEND | O_RDWR;
@@ -83,8 +92,9 @@ int file_open_append(URLContext *h, const char *filename, int flags)
 	}
 
 	fd = open(filename, access, 0666);
-	if (fd < 0)
+	if (fd < 0) {
 		return -ENOENT;
+	}
 	h->priv_data = (void *)(size_t)fd;
 	return 0;
 }
@@ -99,7 +109,7 @@ int file_open_append(URLContext *h, const char *filename, int flags)
  * The remaining functions (for writing, seeking etc.) are set in ffmpeg_init.
  */
 URLProtocol mpeg1_file_protocol = {
-	.name = APPEND_PROTO,
+	.name     = APPEND_PROTO,
 	.url_open = file_open_append
 };
 
@@ -121,9 +131,9 @@ void ffmpeg_init()
 	/* Copy the functions to use for the append file protocol from the standard
 	 * file protocol.
 	 */
-	mpeg1_file_protocol.url_read = file_protocol.url_read;
+	mpeg1_file_protocol.url_read  = file_protocol.url_read;
 	mpeg1_file_protocol.url_write = file_protocol.url_write;
-	mpeg1_file_protocol.url_seek = file_protocol.url_seek;
+	mpeg1_file_protocol.url_seek  = file_protocol.url_seek;
 	mpeg1_file_protocol.url_close = file_protocol.url_close;
 
 	/* Register the append file protocol. */
@@ -134,7 +144,7 @@ void ffmpeg_init()
  * the format is avi; for mpeg1 codec, the format is mpeg. The filename has
  * to be passed, because it gets the appropriate extension appended onto it.
  */
-AVOutputFormat *get_oformat(const char *codec, char *filename)
+AVOutputFormat *get_oformat(struct context *cnt, const char *codec, char *filename)
 {
 	const char *ext;
 	AVOutputFormat *of = NULL;
@@ -148,7 +158,7 @@ AVOutputFormat *get_oformat(const char *codec, char *filename)
 #ifndef FFMPEG_NO_NONSTD_MPEG1
 		|| (strcmp(codec, "mpeg1") == 0)
 #endif 
-		) {
+	) {
 		ext = "mpg";
 		/* We use "mpeg1video" for raw mpeg1 format. Using "mpeg" would
 		 * result in a muxed output file, which isn't appropriate here.
@@ -160,9 +170,7 @@ AVOutputFormat *get_oformat(const char *codec, char *filename)
 		}
 #ifdef FFMPEG_NO_NONSTD_MPEG1
 	} else if (strcmp(codec, "mpeg1") == 0) {
-		const char msg[]="*** mpeg1 support for normal videos has been disabled ***";
-		printf("%s\n", msg);
-		syslog(LOG_ERR, "%s", msg);
+		motion_log(cnt, LOG_ERR, 0, "*** mpeg1 support for normal videos has been disabled ***");
 		return NULL;
 #endif
 	} else if (strcmp(codec, "mpeg4") == 0) {
@@ -176,17 +184,12 @@ AVOutputFormat *get_oformat(const char *codec, char *filename)
 			of->video_codec = CODEC_ID_MSMPEG4V2;
 		}
 	} else {
-		const char msg1[]="ffmpeg_video_codec option value ";
-		const char msg2[]=" is not supported";
-		printf("%s%s%s\n", msg1, codec, msg2);
-		syslog(LOG_ERR, "%s%s%s", msg1, codec, msg2);
+		motion_log(cnt, LOG_ERR, 0, "ffmpeg_video_codec option value %s is not supported", codec);
 		return NULL;
 	}
 
 	if (!of) {
-		const char msg[]="Could not guess format for ";
-		printf("%s%s\n", msg, codec);
-		syslog(LOG_ERR, "%s%s", msg, codec);
+		motion_log(cnt, LOG_ERR, 0, "Could not guess format for %s", codec);
 		return NULL;
 	}
 
@@ -200,8 +203,10 @@ AVOutputFormat *get_oformat(const char *codec, char *filename)
  * mpeg1 with non-standard framerate, the open will fail. Timelapse is a special
  * case and is tested separately.
  */
-struct ffmpeg *ffmpeg_open(char *ffmpeg_video_codec, char *filename, unsigned char *y, 
-	unsigned char *u, unsigned char *v, int width, int height, int rate, int bps, int vbr)
+struct ffmpeg *ffmpeg_open(struct context *cnt, char *ffmpeg_video_codec, 
+                           char *filename, unsigned char *y, unsigned char *u, 
+                           unsigned char *v, int width, int height, int rate, 
+                           int bps, int vbr)
 {
 	AVCodecContext *c;
 	AVCodec *codec;
@@ -213,7 +218,7 @@ struct ffmpeg *ffmpeg_open(char *ffmpeg_video_codec, char *filename, unsigned ch
 	 * FIXME when motion exits we should close the movie to ensure that
 	 * ffmpeg is freed.
 	 */
-	ffmpeg = mymalloc(sizeof(struct ffmpeg));
+	ffmpeg = mymalloc(cnt, sizeof(struct ffmpeg));
 	memset(ffmpeg, 0, sizeof(struct ffmpeg));
 
 	ffmpeg->vbr = vbr;
@@ -224,15 +229,13 @@ struct ffmpeg *ffmpeg_open(char *ffmpeg_video_codec, char *filename, unsigned ch
 	/* allocation the output media context */
 	ffmpeg->oc = av_mallocz(sizeof(AVFormatContext));
 	if (!ffmpeg->oc) {
-		const char msg[]="Memory error while allocating output media context: ";
-		printf("%s%m\n", msg);
-		syslog(LOG_ERR, "%s%m", msg);
+		motion_log(cnt, LOG_ERR, 1, "Memory error while allocating output media context");
 		ffmpeg_cleanups(ffmpeg);
 		return (NULL);
 	}
 
 	/* Setup output format */
-	ffmpeg->oc->oformat = get_oformat(ffmpeg_video_codec, filename);
+	ffmpeg->oc->oformat = get_oformat(cnt, ffmpeg_video_codec, filename);
 	if (!ffmpeg->oc->oformat) {
 		ffmpeg_cleanups(ffmpeg);
 		return NULL;
@@ -245,57 +248,55 @@ struct ffmpeg *ffmpeg_open(char *ffmpeg_video_codec, char *filename, unsigned ch
 	if (ffmpeg->oc->oformat->video_codec != CODEC_ID_NONE) {
 		ffmpeg->video_st = av_new_stream(ffmpeg->oc, 0);
 		if (!ffmpeg->video_st) {
-			const char msg[]="av_new_stream - could not alloc stream: ";
-			printf("%s%m\n", msg);
-			syslog(LOG_ERR, "%s%m", msg);
+			motion_log(cnt, LOG_ERR, 1, "av_new_stream - could not alloc stream");
 			ffmpeg_cleanups(ffmpeg);
 			return (NULL);
 		}
 	} else {
 		/* We did not get a proper video codec. */
-		const char msg[]="Failed to obtain a proper video codec";
-		printf("%s\n", msg);
-		syslog(LOG_ERR, "%s", msg);
+		motion_log(cnt, LOG_ERR, 0, "Failed to obtain a proper video codec");
 		ffmpeg_cleanups(ffmpeg);
 		return (NULL);
 	}
 
-	ffmpeg->c = c = &ffmpeg->video_st->codec;
-	c->codec_id = ffmpeg->oc->oformat->video_codec;
+	ffmpeg->c     = c = AVSTREAM_CODEC_PTR(ffmpeg->video_st);
+	c->codec_id   = ffmpeg->oc->oformat->video_codec;
 	c->codec_type = CODEC_TYPE_VIDEO;
-	is_mpeg1 = c->codec_id == CODEC_ID_MPEG1VIDEO;
+	is_mpeg1      = c->codec_id == CODEC_ID_MPEG1VIDEO;
 
 	/* Uncomment to allow non-standard framerates. */
 	//c->strict_std_compliance = -1;
 
 	/* Set default parameters */
 	c->bit_rate = bps;
-	c->width = width;
-	c->height = height;
-	c->frame_rate = rate;
+	c->width    = width;
+	c->height   = height;
+#if LIBAVCODEC_BUILD >= 4754
+	/* frame rate = 1/time_base, so we set 1/rate, not rate/1 */
+	c->time_base.num = 1;
+	c->time_base.den = rate;
+#else
+	c->frame_rate      = rate;
 	c->frame_rate_base = 1;
+#endif /* LIBAVCODEC_BUILD >= 4754 */
+	
 	if (vbr)
 		c->flags |= CODEC_FLAG_QSCALE;
 
 	/* Set codec specific parameters. */
-	if (is_mpeg1) {
-		/* mpeg1: emit one intra frame every ten frames at most */
-		c->gop_size = 10;
-	} else {
-		/* emit one intra frame every twelve frames at most */	
-		c->gop_size = 12; 
-	}
+	/* set intra frame distance in frames depending on codec */
+	c->gop_size = is_mpeg1 ? 10 : 12;
 	
 	/* some formats want stream headers to be seperate */
-	if(!strcmp(ffmpeg->oc->oformat->name, "mp4") || !strcmp(ffmpeg->oc->oformat->name, "mov") ||
-			!strcmp(ffmpeg->oc->oformat->name, "3gp"))
+	if(!strcmp(ffmpeg->oc->oformat->name, "mp4") || 
+	   !strcmp(ffmpeg->oc->oformat->name, "mov") ||
+	   !strcmp(ffmpeg->oc->oformat->name, "3gp")) {
 		c->flags |= CODEC_FLAG_GLOBAL_HEADER;
+	}
 
 	/* set the output parameters (must be done even if no parameters). */
 	if (av_set_parameters(ffmpeg->oc, NULL) < 0) {
-		const char msg[]="ffmpeg av_set_parameters error: Invalid output format parameters";
-		printf("%s\n", msg);
-		syslog(LOG_ERR, "%s", msg);
+		motion_log(cnt, LOG_ERR, 0, "ffmpeg av_set_parameters error: Invalid output format parameters");
 		ffmpeg_cleanups(ffmpeg);
 		return (NULL);
 	}
@@ -305,23 +306,19 @@ struct ffmpeg *ffmpeg_open(char *ffmpeg_video_codec, char *filename, unsigned ch
 
 	/* Now that all the parameters are set, we can open the video
 		codec and allocate the necessary encode buffers */
-	codec = avcodec_find_encoder(ffmpeg->video_st->codec.codec_id);
+	codec = avcodec_find_encoder(c->codec_id);
 	if (!codec) {
-		const char msg[]="Codec not found: ";
-		printf("%s%m\n", msg);
-		syslog(LOG_ERR, "%s%m", msg);
+		motion_log(cnt, LOG_ERR, 1, "Codec not found");
 		ffmpeg_cleanups(ffmpeg);
 		return (NULL);
 	}
 	
 	/* Set the picture format - need in ffmpeg starting round April-May 2005 */
-	ffmpeg->video_st->codec.pix_fmt=PIX_FMT_YUV420P;
+	c->pix_fmt = PIX_FMT_YUV420P;
 
 	/* open the codec */
-	if (avcodec_open(&ffmpeg->video_st->codec, codec) < 0) {
-		const char msg[]="avcodec_open - could not open codec: ";
-		printf("%s%m\n", msg);
-		syslog(LOG_ERR, "%s%m", msg);
+	if (avcodec_open(c, codec) < 0) {
+		motion_log(cnt, LOG_ERR, 1, "avcodec_open - could not open codec");
 		ffmpeg_cleanups(ffmpeg);
 		return (NULL);
 	}
@@ -331,22 +328,21 @@ struct ffmpeg *ffmpeg_open(char *ffmpeg_video_codec, char *filename, unsigned ch
 		/* allocate output buffer */
 		/* XXX: API change will be done */
 		ffmpeg->video_outbuf_size = 200000;
-		ffmpeg->video_outbuf = mymalloc(ffmpeg->video_outbuf_size);
+		ffmpeg->video_outbuf = mymalloc(cnt, ffmpeg->video_outbuf_size);
 	}
 
 	/* allocate the encoded raw picture */
 	ffmpeg->picture = avcodec_alloc_frame();
 	if (!ffmpeg->picture) {
-		const char msg[]="avcodec_alloc_frame - could not alloc frame: ";
-		printf("%s%m\n", msg);
-		syslog(LOG_ERR, "%s%m", msg);
+		motion_log(cnt, LOG_ERR, 1, "avcodec_alloc_frame - could not alloc frame");
 		ffmpeg_cleanups(ffmpeg);
 		return (NULL);
 	}
 
 	/* set variable bitrate if requested */
-	if (ffmpeg->vbr)
+	if (ffmpeg->vbr) {
 		ffmpeg->picture->quality = ffmpeg->vbr;
+	}
 
 	/* set the frame data */
 	ffmpeg->picture->data[0] = y;
@@ -373,34 +369,27 @@ struct ffmpeg *ffmpeg_open(char *ffmpeg_video_codec, char *filename, unsigned ch
 			/* path did not exist? */
 			if (errno == ENOENT) {
 				/* create path for file (don't use file_proto)... */
-				if (create_path(filename) == -1) {
+				if (create_path(cnt, filename) == -1) {
 					ffmpeg_cleanups(ffmpeg);
 					return (NULL);
 				}
 
 				/* and retry opening the file (use file_proto) */
 				if (url_fopen(&ffmpeg->oc->pb, file_proto, URL_WRONLY) < 0) {
-					const char msg[]="url_fopen - error opening file ";
-					printf("%s%s: %s\n", msg, filename, strerror(errno));
-					syslog(LOG_ERR, "%s%s: %s", msg, filename, strerror(errno));
+					motion_log(cnt, LOG_ERR, 1, "url_fopen - error opening file %s",filename);
 					ffmpeg_cleanups(ffmpeg);
 					return (NULL);
 				}
 				/* Permission denied */
 			} else if (errno ==  EACCES) {
-				const char msg1[]="url_fopen - error opening file ";
-				const char msg2[]=" ... check access rights to target directory";
-				printf("%s%s: %s%s\n",
-					msg1, filename, strerror(errno), msg2);
-				syslog(LOG_ERR, "%s%s: %s%s",
-					msg1, filename, strerror(errno), msg2);
+				motion_log(cnt, LOG_ERR, 1,
+				           "url_fopen - error opening file %s"
+				           " ... check access rights to target directory", filename);
 				/* create path for file... */
 				ffmpeg_cleanups(ffmpeg);
 				return (NULL);
 			} else {
-				const char msg[]="Error opening file ";
-				printf("%s%s: %s\n", msg, filename, strerror(errno));
-				syslog(LOG_ERR, "%s%s: %s", msg, filename, strerror(errno));
+				motion_log(cnt, LOG_ERR, 1, "Error opening file %s", filename);
 				ffmpeg_cleanups(ffmpeg);
 				return (NULL);
 			}
@@ -422,7 +411,7 @@ void ffmpeg_cleanups(struct ffmpeg *ffmpeg)
 
 	/* close each codec */
 	if (ffmpeg->video_st) {
-		avcodec_close(&ffmpeg->video_st->codec);
+		avcodec_close(AVSTREAM_CODEC_PTR(ffmpeg->video_st));
 		av_freep(&ffmpeg->picture);
 		av_freep(&ffmpeg->video_outbuf);
 	}
@@ -450,7 +439,7 @@ void ffmpeg_close(struct ffmpeg *ffmpeg)
 
 	/* close each codec */
 	if (ffmpeg->video_st) {
-		avcodec_close(&ffmpeg->video_st->codec);
+		avcodec_close(AVSTREAM_CODEC_PTR(ffmpeg->video_st));
 		av_freep(&ffmpeg->picture);
 		av_freep(&ffmpeg->video_outbuf);
 	}
@@ -475,21 +464,22 @@ void ffmpeg_close(struct ffmpeg *ffmpeg)
 }
 
 /* Puts the image pointed to by ffmpeg->picture. */
-void ffmpeg_put_image(struct ffmpeg *ffmpeg) 
+void ffmpeg_put_image(struct context *cnt, struct ffmpeg *ffmpeg) 
 {
-	ffmpeg_put_frame(ffmpeg, ffmpeg->picture);
+	ffmpeg_put_frame(cnt, ffmpeg, ffmpeg->picture);
 }
 
 /* Puts an arbitrary picture defined by y, u and v. */
-void ffmpeg_put_other_image(struct ffmpeg *ffmpeg, unsigned char *y, unsigned char *u, 
-	unsigned char *v)
+void ffmpeg_put_other_image(struct context *cnt, struct ffmpeg *ffmpeg, 
+                            unsigned char *y, unsigned char *u, 
+                            unsigned char *v)
 {
 	AVFrame *picture;
 	/* allocate the encoded raw picture */
-	picture = ffmpeg_prepare_frame(ffmpeg, y, u, v);
+	picture = ffmpeg_prepare_frame(cnt, ffmpeg, y, u, v);
 
 	if (picture) {
-		ffmpeg_put_frame(ffmpeg, picture);
+		ffmpeg_put_frame(cnt, ffmpeg, picture);
 		free(picture);
 	}
 }
@@ -497,7 +487,7 @@ void ffmpeg_put_other_image(struct ffmpeg *ffmpeg, unsigned char *y, unsigned ch
 /* Encodes and writes a video frame using the av_write_frame API. This is
  * a helper function for ffmpeg_put_image and ffmpeg_put_other_image. 
  */
-void ffmpeg_put_frame(struct ffmpeg *ffmpeg, AVFrame *pic)
+void ffmpeg_put_frame(struct context *cnt, struct ffmpeg *ffmpeg, AVFrame *pic)
 {
 	int out_size, ret;
 #ifdef FFMPEG_AVWRITEFRAME_NEWAPI
@@ -505,7 +495,7 @@ void ffmpeg_put_frame(struct ffmpeg *ffmpeg, AVFrame *pic)
 
 	av_init_packet(&pkt); /* init static structure */
 	pkt.stream_index = ffmpeg->video_st->index;
-#endif
+#endif /* FFMPEG_AVWRITEFRAME_NEWAPI */
 
 	if (ffmpeg->oc->oformat->flags & AVFMT_RAWPICTURE) {
 		/* raw video case. The API will change slightly in the near future for that */
@@ -517,36 +507,36 @@ void ffmpeg_put_frame(struct ffmpeg *ffmpeg, AVFrame *pic)
 #else
 		ret = av_write_frame(ffmpeg->oc, ffmpeg->video_st->index,
 			(uint8_t *)pic, sizeof(AVPicture));
-#endif
+#endif /* FFMPEG_AVWRITEFRAME_NEWAPI */
 	} else {
 		/* encode the image */
-		out_size = avcodec_encode_video(&ffmpeg->video_st->codec, ffmpeg->video_outbuf, 
-			ffmpeg->video_outbuf_size, pic);
+		out_size = avcodec_encode_video(AVSTREAM_CODEC_PTR(ffmpeg->video_st),
+		                                ffmpeg->video_outbuf, 
+		                                ffmpeg->video_outbuf_size, pic);
 
 		/* if zero size, it means the image was buffered */
 		if (out_size != 0) {
 			/* write the compressed frame in the media file */
 			/* XXX: in case of B frames, the pts is not yet valid */
 #ifdef FFMPEG_AVWRITEFRAME_NEWAPI
-			pkt.pts = ffmpeg->video_st->codec.coded_frame->pts;
-			if(ffmpeg->video_st->codec.coded_frame->key_frame)
+			pkt.pts = AVSTREAM_CODEC_PTR(ffmpeg->video_st)->coded_frame->pts;
+			if (AVSTREAM_CODEC_PTR(ffmpeg->video_st)->coded_frame->key_frame) {
 				pkt.flags |= PKT_FLAG_KEY;
+			}
 			pkt.data = ffmpeg->video_outbuf;
 			pkt.size = out_size;
 			ret = av_write_frame(ffmpeg->oc, &pkt);
 #else
-			ret = av_write_frame(ffmpeg->oc, ffmpeg->video_st->index, ffmpeg->video_outbuf, 
-				out_size);
-#endif
+			ret = av_write_frame(ffmpeg->oc, ffmpeg->video_st->index, 
+			                     ffmpeg->video_outbuf, out_size);
+#endif /* FFMPEG_AVWRITEFRAME_NEWAPI */
 		} else {
 			ret = 0;
 		}
 	}
 	
 	if (ret != 0) {
-		const char msg[]="Error while writing video frame: ";
-		printf("%s%m\n", msg);
-		syslog(LOG_ERR, "%s%m", msg);
+		motion_log(cnt, LOG_ERR, 1, "Error while writing video frame");
 		return;
 	}
 }
@@ -558,22 +548,22 @@ void ffmpeg_put_frame(struct ffmpeg *ffmpeg, AVFrame *pic)
  *
  * The returned AVFrame pointer must be freed after use.
  */
-AVFrame *ffmpeg_prepare_frame(struct ffmpeg *ffmpeg, unsigned char *y, unsigned char *u, 
-	unsigned char *v)
+AVFrame *ffmpeg_prepare_frame(struct context *cnt, struct ffmpeg *ffmpeg, 
+                              unsigned char *y, unsigned char *u, 
+                              unsigned char *v)
 {
 	AVFrame *picture;
 
 	picture = avcodec_alloc_frame();
 	if (!picture) {
-		const char msg[]="Could not alloc frame: ";
-		printf("%s%m\n", msg);
-		syslog(LOG_ERR, "%s%m", msg);
+		motion_log(cnt, LOG_ERR, 1, "Could not alloc frame");
 		return NULL;
 	}
 
 	/* take care of variable bitrate setting */
-	if (ffmpeg->vbr)
+	if (ffmpeg->vbr) {
 		picture->quality = ffmpeg->vbr;
+	}
 	
 	/* setup pointers and line widths */
 	picture->data[0] = y;
