@@ -37,6 +37,7 @@ void ffmpeg_init(void);
  * timelapse video, use TIMELAPSE_CODEC as codec name.
  */
 struct ffmpeg *ffmpeg_open(
+	struct context *cnt,
 	char *ffmpeg_video_codec, 
 	char *filename, 
 	unsigned char *y,    /* YUV420 Y plane */
@@ -50,10 +51,11 @@ struct ffmpeg *ffmpeg_open(
 	);
 
 /* Puts the image pointed to by the picture member of struct ffmpeg. */
-void ffmpeg_put_image(struct ffmpeg *);
+void ffmpeg_put_image(struct context *cnt, struct ffmpeg *);
 
 /* Puts the image defined by u, y and v (YUV420 format). */
 void ffmpeg_put_other_image(
+	struct context *cnt,
 	struct ffmpeg *ffmpeg, 
 	unsigned char *y, 
 	unsigned char *u, 
