@@ -16,9 +16,10 @@ void overlay_smartmask(struct context *, unsigned char *);
 void overlay_fixed_mask(struct context *, unsigned char *);
 void put_fixed_mask(struct context *, char *);
 void overlay_largest_label(struct context *, unsigned char *);
-void put_picture_fd (struct context *, FILE *, char *, int);
-void put_picture (struct context *, char *, char *, int );
-char *get_pgm (struct context *, FILE *, int, int);
+void put_picture_fd (struct context *, FILE *, unsigned char *, int);
+int put_picture_memory (struct context *, unsigned char*, int, unsigned char *, int);
+void put_picture (struct context *, char *, unsigned char *, int );
+unsigned char *get_pgm (struct context *, FILE *, int, int);
 void preview_best(struct context *);
 
 #endif /* _INCLUDE_PICTURE_H_ */
