@@ -58,8 +58,7 @@ int track_center(struct context *cnt, int dev, int manual, int xoff, int yoff)
 	else if (cnt->track.type == TRACK_TYPE_GENERIC)
 		return 10; // FIX ME. I chose to return something reasonable.
 
-	printf("[%d] track_move: internal error, %d is not a known track-type\n", cnt->threadnr, cnt->track.type);
-	syslog(LOG_ERR, "[%d] track_move: internal error, %d is not a known track-type", cnt->threadnr, cnt->track.type);
+	motion_log(cnt, LOG_ERR, 1, "track_move: internal error, %d is not a known track-type", cnt->track.type);
 
 	return 0;
 }
@@ -78,8 +77,7 @@ int track_move(struct context *cnt, int dev, int pipe, int mpipe, struct coord *
 	else if (cnt->track.type == TRACK_TYPE_GENERIC)
 		return 0; // FIX ME. I chose to return something reasonable.
 
-	printf("[%d] track_move: internal error, %d is not a known track-type\n", cnt->threadnr, cnt->track.type);
-	syslog(LOG_ERR, "[%d] track_move: internal error, %d is not a known track-type", cnt->threadnr, cnt->track.type);
+	motion_log(cnt, LOG_ERR, 1, "track_move: internal error, %d is not a known track-type", cnt->track.type);
 
 	return 0;
 }
@@ -105,8 +103,7 @@ static int stepper_command(struct context *cnt, int motor, int command, int n)
 
 	while (read(cnt->track.dev, buffer, 1)!=1 && time(NULL) < timeout+1);
 	if (time(NULL) >= timeout+2) {
-		printf("[%d] Status byte timeout!\n", cnt->threadnr);
-		syslog(LOG_ERR, "[%d] Status byte timeout!", cnt->threadnr);
+		motion_log(cnt, LOG_ERR, 1, "Status byte timeout!");
 		return 0;
 	}
 	return buffer[0];
@@ -125,9 +122,7 @@ static int stepper_center(struct context *cnt, int xoff, int yoff)
 
 	if (cnt->track.dev<0) {
 		if ((cnt->track.dev=open(cnt->track.port, O_RDWR | O_NOCTTY)) < 0) {
-			const char msg[]="Unable to open serial device ";
-			printf("[%d] %s%s: %m\n", cnt->threadnr, msg, cnt->track.port);
-			syslog(LOG_ERR, "[%d] %s%s: %m", cnt->threadnr, msg, cnt->track.port);
+			motion_log(cnt, LOG_ERR, 1, "Unable to open serial device %s", cnt->track.port);
 			exit(1);
 		}
 		bzero (&adtio, sizeof(adtio));
@@ -139,9 +134,7 @@ static int stepper_center(struct context *cnt, int xoff, int yoff)
 		adtio.c_cc[VMIN]=0;	/* blocking read until 1 char */
 		tcflush (cnt->track.dev, TCIFLUSH);
 		if (tcsetattr(cnt->track.dev, TCSANOW, &adtio) < 0) {
-			const char msg[]="Unable to initialize serial device ";
-			printf("[%d] %s%s: %m\n", cnt->threadnr, msg, cnt->track.port);
-			syslog(LOG_ERR, "[%d] %s%s: %m", cnt->threadnr, msg, cnt->track.port);
+			motion_log(cnt, LOG_ERR, 1, "Unable to initialize serial device %s", cnt->track.port);
 			exit(1);
 		}
 	}
@@ -197,9 +190,7 @@ static char iomojo_command(struct context *cnt, char *command, int len, int ret)
 	if (ret) {
 		while (read(cnt->track.dev, buffer, 1)!=1 && time(NULL) < timeout+2);
 		if (time(NULL) >= timeout+2) {
-			const char msg[]="Return byte timeout!";
-			printf("[%d] %s\n", cnt->threadnr, msg);
-			syslog(LOG_ERR, "[%d] %s", cnt->threadnr, msg);
+			motion_log(cnt, LOG_ERR, 1, "Return byte timeout!");
 			return 0;
 		}
 	}
@@ -214,11 +205,8 @@ static void iomojo_setspeed(struct context *cnt, int speed)
 	command[1]=cnt->track.iomojo_id;
 	command[2]=speed;
 	
-	if (iomojo_command(cnt, command, 3, 1)!=IOMOJO_SETSPEED_RET){
-		const char msg[]="Unable to set camera speed";
-		printf("[%d] %s\n", cnt->threadnr, msg);
-		syslog(LOG_ERR, "[%d] %s", cnt->threadnr, msg);
-	}
+	if (iomojo_command(cnt, command, 3, 1)!=IOMOJO_SETSPEED_RET)
+		motion_log(cnt, LOG_ERR, 1, "Unable to set camera speed");
 }
 
 static void iomojo_movehome(struct context *cnt)
@@ -238,9 +226,7 @@ static int iomojo_center(struct context *cnt, int xoff, int yoff)
 
 	if (cnt->track.dev<0) {
 		if ((cnt->track.dev=open(cnt->track.port, O_RDWR | O_NOCTTY)) < 0) {
-			const char msg[]="Unable to open serial device ";
-			printf("[%d] %s%s: %m\n", cnt->threadnr, msg, cnt->track.port);
-			syslog(LOG_ERR, "[%d] %s%s: %m", cnt->threadnr, msg, cnt->track.port);
+			motion_log(cnt, LOG_ERR, 1, "Unable to open serial device %s", cnt->track.port);
 			return 0;
 		}
 		bzero (&adtio, sizeof(adtio));
@@ -252,9 +238,7 @@ static int iomojo_center(struct context *cnt, int xoff, int yoff)
 		adtio.c_cc[VMIN]=0;	/* blocking read until 1 char */
 		tcflush (cnt->track.dev, TCIFLUSH);
 		if (tcsetattr(cnt->track.dev, TCSANOW, &adtio) < 0) {
-			const char msg[]="Unable to initialize serial device ";
-			printf("[%d] %s%s: %m\n", cnt->threadnr, msg, cnt->track.port);
-			syslog(LOG_ERR, "[%d] %s%s: %m", cnt->threadnr, msg, cnt->track.port);
+			motion_log(cnt, LOG_ERR, 1, "Unable to initialize serial device %s", cnt->track.port);
 			return 0;
 		}
 	}
@@ -348,17 +332,17 @@ static int lqos_center(struct context *cnt, int dev, int xoff, int yoff)
 	struct pwc_mpt_range pmr;
 
 	if (cnt->track.dev==-1) {
+
 		if (ioctl(dev, VIDIOCPWCMPTRESET, &reset) == -1) {
-			const char msg[]="Failed to reset camera to starting position! Reason: ";
-			printf("[%d] %s%m\n", cnt->threadnr, msg);
-			syslog(LOG_ERR, "[%d] %s%m", cnt->threadnr, msg);
+			motion_log(cnt, LOG_ERR, 1, "Failed to reset camera to starting position! Reason");
 			return 0;
 		}
-		sleep(6);
+
+		// sleep(6) replaced 
+		SLEEP(6,0)	
+
 		if (ioctl(dev, VIDIOCPWCMPTGRANGE, &pmr) == -1) {
-			const char msg[]="failed VIDIOCPWCMPTGRANGE ";
-			printf("[%d] %s%m\n", cnt->threadnr, msg);
-			syslog(LOG_ERR, "[%d] %s%m", cnt->threadnr, msg);
+			motion_log(cnt, LOG_ERR, 1, "failed VIDIOCPWCMPTGRANGE");
 			return 0;
 		}
 		cnt->track.dev=dev;
@@ -368,20 +352,16 @@ static int lqos_center(struct context *cnt, int dev, int xoff, int yoff)
 		cnt->track.tiltmin=pmr.tilt_min;
 		cnt->track.tiltmax=pmr.tilt_max;
 	}
-	if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1) {
-		const char msg[]="ioctl VIDIOCPWCMPTGANGLE: ";
-		printf("[%d] %s%m\n", cnt->threadnr, msg);
-		syslog(LOG_ERR, "[%d] %s%m", cnt->threadnr, msg);
-	}
+	if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1)
+		motion_log(cnt, LOG_ERR, 1, "ioctl VIDIOCPWCMPTGANGLE");
+	
 	pma.absolute=1;
 	if (xoff*100 < cnt->track.panmax && xoff*100 > cnt->track.panmin)
 		pma.pan = xoff*100;
 	if (yoff*100 < cnt->track.tiltmax && yoff*100 > cnt->track.tiltmin)
 		pma.tilt = yoff*100;
 	if (ioctl(dev, VIDIOCPWCMPTSANGLE, &pma) == -1) {
-		const char msg[]="Failed to pan/tilt camera! Reason: ";
-		printf("[%d] %s%m\n", cnt->threadnr, msg);
-		syslog(LOG_ERR, "[%d] %s%m", cnt->threadnr, msg);
+		motion_log(cnt, LOG_ERR, 1, "Failed to pan/tilt camera! Reason");
 		return 0;
 	}
 
@@ -414,9 +394,7 @@ static int lqos_move(struct context *cnt, int dev, int pipe, int mpipe,
 	/* If we never checked for the min/max values for pan/tilt we do it now */
 	if (cnt->track.minmaxfound==0) {
 		if (ioctl(dev, VIDIOCPWCMPTGRANGE, &pmr) == -1) {
-			const char msg[]="failed VIDIOCPWCMPTGRANGE ";
-			printf("[%d] %s%m\n", cnt->threadnr, msg);
-			syslog(LOG_ERR, "[%d] %s%m", cnt->threadnr, msg);
+			motion_log(cnt, LOG_ERR, 1, "failed VIDIOCPWCMPTGRANGE");
 			return 0;
 		}
 		cnt->track.minmaxfound=1;
@@ -427,11 +405,9 @@ static int lqos_move(struct context *cnt, int dev, int pipe, int mpipe,
 	}
 
 	/* Get current camera position */
-	if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1) {
-		const char msg[]="ioctl VIDIOCPWCMPTGANGLE: ";
-		printf("[%d] %s%m\n", cnt->threadnr, msg);
-		syslog(LOG_ERR, "[%d] %s%m", cnt->threadnr, msg);
-	}
+	if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1)
+		motion_log(cnt, LOG_ERR, 1, "ioctl VIDIOCPWCMPTGANGLE");
+
 
 	/* Check current position of camera and see if we need to adjust
 	   values down to what is left to move */
@@ -449,9 +425,7 @@ static int lqos_move(struct context *cnt, int dev, int pipe, int mpipe,
 	pma.pan = move_x_degrees;
 	pma.tilt = move_y_degrees;
 	if (ioctl(dev, VIDIOCPWCMPTSANGLE, &pma) == -1) {
-		const char msg[]="Failed to pan/tilt camera! Reason: ";
-		printf("[%d] %s%m\n", cnt->threadnr, msg);
-		syslog(LOG_ERR, "[%d] %s%m", cnt->threadnr, msg);
+		motion_log(cnt, LOG_ERR, 1, "Failed to pan/tilt camera! Reason");
 		return 0;
 	}
 
