@@ -27,19 +27,17 @@
 #define MAX2(x, y) ((x) > (y) ? (x) : (y))
 #define MIN2(x, y) ((x) < (y) ? (x) : (y))
 
-static void v4l_picture_controls(struct video_dev *viddev, struct context *cnt)
+static void v4l_picture_controls(struct context *cnt, struct video_dev *viddev)
 {
 	int dev=viddev->fd;
-	unsigned char *image = cnt->imgs.new;
+	unsigned char *image = cnt->imgs.image_ring_buffer;
 	struct video_picture vid_pic;
 	int make_change = 0;
 
 	if (cnt->conf.contrast && cnt->conf.contrast != viddev->contrast) {
 
-		if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1) {
-			printf("[%d] ioctl (VIDIOCGPICT): %m\n", cnt->threadnr);
-			syslog(LOG_ERR, "[%d] ioctl (VIDIOCGPICT): %m", cnt->threadnr);
-		}
+		if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1)
+			motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGPICT)");
 
 		make_change = 1;
 		vid_pic.contrast = cnt->conf.contrast * 256;
@@ -49,10 +47,8 @@ static void v4l_picture_controls(struct video_dev *viddev, struct context *cnt)
 	if (cnt->conf.saturation && cnt->conf.saturation != viddev->saturation) {
 
 		if (!make_change) {
-			if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1) {
-				printf("[%d] ioctl (VIDIOCGPICT): %m\n", cnt->threadnr);
-				syslog(LOG_ERR, "{%d] ioctl (VIDIOCGPICT): %m", cnt->threadnr);
-			}
+			if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1)
+				motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGPICT)");
 		}
 
 		make_change = 1;
@@ -63,10 +59,8 @@ static void v4l_picture_controls(struct video_dev *viddev, struct context *cnt)
 	if (cnt->conf.hue && cnt->conf.hue != viddev->hue) {
 
 		if (!make_change) {
-			if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1) {
-				printf("[%d] ioctl (VIDIOCGPICT): %m\n", cnt->threadnr);
-				syslog(LOG_ERR, "[%d] ioctl (VIDIOCGPICT): %m", cnt->threadnr);
-			}
+			if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1)
+				motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGPICT)");
 		}
 
 		make_change = 1;
@@ -90,7 +84,7 @@ static void v4l_picture_controls(struct video_dev *viddev, struct context *cnt)
 		brightness_window_low = MAX2(brightness_target - 10, 1);
 		
 		for (i = 0; i < cnt->imgs.motionsize; i += 101) {
-			avg += *image++;
+			avg += image[i];
 			j++;
 		}
 		avg = avg / j;
@@ -98,15 +92,13 @@ static void v4l_picture_controls(struct video_dev *viddev, struct context *cnt)
 		if (avg > brightness_window_high || avg < brightness_window_low) {
 			/* If we already read the VIDIOGPICT - we should not do it again */
 			if (!make_change) {
-				if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1) {
-					printf("[%d] ioctl (VIDIOCGPICT): %m\n", cnt->threadnr);
-					syslog(LOG_ERR, "[%d] ioctl (VIDIOCGPICT): %m", cnt->threadnr);
-				}
+				if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1)
+					motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGPICT)");
 			}
 			/* average is above window - turn down brigtness - go for the target */
 			if (avg > brightness_window_high) {
-				step = MIN2((avg - brightness_target)/5+1, viddev->brightness - 1);
-				if (viddev->brightness > 1 ) {
+				step = MIN2((avg - brightness_target)/5+1, viddev->brightness);
+				if (viddev->brightness > step+1) {
 					viddev->brightness -= step;
 					vid_pic.brightness = viddev->brightness * 256;
 					make_change = 1;
@@ -115,7 +107,7 @@ static void v4l_picture_controls(struct video_dev *viddev, struct context *cnt)
 			/* average is below window - turn up brigtness - go for the target */
 			if (avg < brightness_window_low) {
 				step = MIN2((brightness_target - avg)/5+1, 255 - viddev->brightness);
-				if (viddev->brightness < 255 ) {
+				if (viddev->brightness < 255-step ) {
 					viddev->brightness += step;
 					vid_pic.brightness = viddev->brightness * 256;
 					make_change = 1;
@@ -125,10 +117,8 @@ static void v4l_picture_controls(struct video_dev *viddev, struct context *cnt)
 	} else {
 		if (cnt->conf.brightness && cnt->conf.brightness != viddev->brightness) {
 			if (!make_change) {
-				if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1) {
-					printf("[%d] ioctl (VIDIOCGPICT): %m\n", cnt->threadnr);
-					syslog(LOG_ERR, "[%d] ioctl (VIDIOCGPICT): %m", cnt->threadnr);
-				}
+				if (ioctl(dev, VIDIOCGPICT, &vid_pic)==-1)
+					motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGPICT)");
 			}
 	
 			make_change = 1;
@@ -138,10 +128,8 @@ static void v4l_picture_controls(struct video_dev *viddev, struct context *cnt)
 	}
 
 	if (make_change) {
-		if (ioctl(dev, VIDIOCSPICT, &vid_pic)==-1) {
-			printf("[%d] ioctl (VIDIOCSPICT): %m\n", cnt->threadnr);
-			syslog(LOG_ERR, "[%d] ioctl (VIDIOCSPICT): %m", cnt->threadnr);
-		}
+		if (ioctl(dev, VIDIOCSPICT, &vid_pic)==-1)
+			motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCSPICT)");
 	}
 }
 		
@@ -225,8 +213,8 @@ void rgb24toyuv420p(unsigned char *map, unsigned char *cap_map, int width, int h
 */
 
 
-static char *v4l_start (struct video_dev *viddev, int width, int height, int input, int norm,
-                        unsigned long freq, int tuner_number, struct context *cnt)
+static unsigned char *v4l_start(struct context *cnt, struct video_dev *viddev, int width, int height, int input, int norm,
+                        unsigned long freq, int tuner_number)
 {
 	int dev=viddev->fd;
 	struct video_capability vid_caps;
@@ -235,11 +223,10 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 	struct video_window vid_win;
 	struct video_mbuf vid_buf;
 	struct video_mmap vid_mmap;
-	char *map;
+	unsigned char *map;
 
 	if (ioctl (dev, VIDIOCGCAP, &vid_caps) == -1) {
-		printf("[%d] ioctl (VIDIOCGCAP): %m\n", cnt->threadnr);
-		syslog(LOG_ERR, "[%d] ioctl (VIDIOCGCAP): %m", cnt->threadnr);
+		motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGCAP)");
 		return (NULL);
 	}
 	if (vid_caps.type & VID_TYPE_MONOCHROME) viddev->v4l_fmt=VIDEO_PALETTE_GREY;
@@ -247,14 +234,12 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 		memset(&vid_chnl, 0, sizeof(struct video_channel));
 		vid_chnl.channel = input;
 		if (ioctl (dev, VIDIOCGCHAN, &vid_chnl) == -1) {
-			printf("[%d] ioctl (VIDIOCGCHAN): %m\n", cnt->threadnr);
-			syslog(LOG_ERR, "[%d] ioctl (VIDIOCGCHAN): %m", cnt->threadnr);
+			motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGCHAN)");
 		} else {
 			vid_chnl.channel = input;
 			vid_chnl.norm    = norm;
 			if (ioctl (dev, VIDIOCSCHAN, &vid_chnl) == -1) {
-				printf("[%d] ioctl (VIDIOCSCHAN): %m\n", cnt->threadnr);
-				syslog(LOG_ERR, "[%d] ioctl (VIDIOCSCHAN): %m", cnt->threadnr);
+				motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCSCHAN)");
 				return (NULL);
 			}
 		}
@@ -262,8 +247,7 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 	if (freq) {
 		vid_tuner.tuner = tuner_number;
 		if (ioctl (dev, VIDIOCGTUNER, &vid_tuner)==-1) {
-			printf("[%d] ioctl (VIDIOCGTUNER): %m\n", cnt->threadnr);
-			syslog(LOG_ERR, "[%d] ioctl (VIDIOCGTUNER): %m", cnt->threadnr);
+			motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGTUNER)");
 		} else {
 			if (vid_tuner.flags & VIDEO_TUNER_LOW) {
 				freq=freq*16; /* steps of 1/16 KHz */
@@ -271,40 +255,32 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 				freq=(freq*10)/625;
 			}
 			if (ioctl(dev, VIDIOCSFREQ, &freq)==-1) {
-				printf("[%d] ioctl (VIDIOCSFREQ): %m\n", cnt->threadnr);
-				syslog(LOG_ERR, "[%d] ioctl (VIDIOCSFREQ): %m", cnt->threadnr);
+				motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCSFREQ)");
 				return (NULL);
 			}
 			if (cnt->conf.setup_mode)
-				printf("[%d] Frequency set\n", cnt->threadnr);
+				motion_log(cnt, -1, 0, "Frequency set");
 		}
 	}
 	if (ioctl (dev, VIDIOCGMBUF, &vid_buf) == -1) {
-		const char msg[]="No mmap falling back on read";
-		const char msg1[]="V4L capturing using read is deprecated!";
-		const char msg2[]="Motion now only supports mmap.";
-		printf("[%d] %s\n", cnt->threadnr, msg);
-		syslog(LOG_WARNING, "[%d] %s", cnt->threadnr, msg);
+		motion_log(cnt, LOG_WARNING, 0, "No mmap falling back on read");
 		if (ioctl (dev, VIDIOCGWIN, &vid_win)== -1) {
-			printf("[%d] ioctl VIDIOCGWIN: %m\n", cnt->threadnr);
-			syslog(LOG_ERR, "[%d] ioctl VIDIOCGWIN: %m", cnt->threadnr);
+			motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGWIN)");
 			return (NULL);
 		}
 		vid_win.width=width;
 		vid_win.height=height;
 		vid_win.clipcount=0;
 		if (ioctl (dev, VIDIOCSWIN, &vid_win)== -1) {
-			printf("[%d] ioctl VIDIOCSWIN: %m\n",cnt->threadnr);
-			syslog(LOG_ERR, "[%d] ioctl VIDIOCSWIN: %m", cnt->threadnr);
+			motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCSWIN)");
 			return (NULL);
 		}
-		syslog(LOG_WARNING, "[%d] %s", cnt->threadnr, msg1);
-		syslog(LOG_WARNING, "[%d] %s", cnt->threadnr, msg2);
-		printf("[%d] %s\n", cnt->threadnr, msg1);
-		printf("[%d] %s\n", cnt->threadnr, msg2);
-		exit(1);
+		motion_log(cnt, LOG_WARNING, 0, "V4L capturing using read is deprecated!");
+		motion_log(cnt, LOG_WARNING, 0, "Motion now only supports mmap.");
+		motion_log(cnt, LOG_WARNING, 0, "Motion Exits.");
+		exit(1);  //FIXME - This seems like an old oops that was never cleaned out or fixed
 		viddev->v4l_read_img=1;
-		map=mymalloc(width*height*3);
+		map=mymalloc(cnt ,width*height*3);
 		viddev->v4l_maxbuffer=1;
 		viddev->v4l_curbuffer=0;
 		viddev->v4l_buffers[0]=map;
@@ -329,23 +305,25 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 		vid_mmap.width=width;
 		vid_mmap.height=height;
 		if (ioctl(dev, VIDIOCMCAPTURE, &vid_mmap) == -1) {
-			const char msg[]="Failed with YUV420P, trying YUV422 palette";
-			printf("[%d] %s\n", cnt->threadnr, msg);
-			syslog(LOG_DEBUG, "[%d] %s", cnt->threadnr, msg);
+			motion_log(cnt, LOG_DEBUG, 1, "Failed with YUV420P, trying YUV422 palette");
 			viddev->v4l_fmt=VIDEO_PALETTE_YUV422;
 			vid_mmap.format=viddev->v4l_fmt;
 			/* Try again... */
 			if (ioctl(dev, VIDIOCMCAPTURE, &vid_mmap) == -1) {
-				const char msg[]="Failed with YUV422, trying RGB24 palette";
-				printf("[%d] %s\n", cnt->threadnr, msg);
-				syslog(LOG_DEBUG, "[%d] %s", cnt->threadnr, msg);
+				motion_log(cnt, LOG_DEBUG, 1, "Failed with YUV422, trying RGB24 palette");
 				viddev->v4l_fmt=VIDEO_PALETTE_RGB24;
 				vid_mmap.format=viddev->v4l_fmt;
 				/* Try again... */
 				if (ioctl(dev, VIDIOCMCAPTURE, &vid_mmap) == -1) {
-					printf("[%d] ioctl VIDIOCMCAPTURE: %m\n", cnt->threadnr);
-					syslog(LOG_ERR, "[%d] ioctl VIDIOCMCAPTURE: %m", cnt->threadnr);
-					return (NULL);
+					motion_log(cnt, LOG_DEBUG, 1, "Failed with RGB24, trying GREYSCALE palette");
+					viddev->v4l_fmt=VIDEO_PALETTE_GREY;
+					vid_mmap.format=viddev->v4l_fmt;
+					/* Try one last time... */
+					if (ioctl(dev, VIDIOCMCAPTURE, &vid_mmap) == -1) {
+						motion_log(cnt, LOG_ERR, 1, "Failed with all supported palettes "
+						                            "- giving up");
+						return (NULL);
+					}
 				}
 			}
 		}
@@ -368,7 +346,22 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 	return map;
 }
 
-static char *v4l_next (struct video_dev *viddev, unsigned char *map, int width, int height, struct context *cnt)
+
+/**
+ * v4l_next fetches a video frame from a v4l device
+ * Parameters:
+ *     cnt        Pointer to the context for this thread
+ *     viddev     Pointer to struct containing video device handle
+ *     map        Pointer to the buffer in which the function puts the new image
+ *     width      Width of image in pixels
+ *     height     Height of image in pixels
+ *
+ * Returns
+ *     0          Success
+ *    -1          Fatal error
+ *     1          Non fatal error (not implemented)
+ */
+int v4l_next(struct context *cnt, struct video_dev *viddev, unsigned char *map, int width, int height)
 {
 	int dev=viddev->fd;
 	int frame=viddev->v4l_curbuffer;
@@ -379,7 +372,7 @@ static char *v4l_next (struct video_dev *viddev, unsigned char *map, int width,
 
 	if (viddev->v4l_read_img) {
 		if (read(dev, map, viddev->v4l_bufsize) != viddev->v4l_bufsize)
-			return NULL;
+			return -1;
 	} else {
 		vid_mmap.format=viddev->v4l_fmt;
 		vid_mmap.width=width;
@@ -400,22 +393,18 @@ static char *v4l_next (struct video_dev *viddev, unsigned char *map, int width,
 		vid_mmap.frame=viddev->v4l_curbuffer;
 
 		if (ioctl(dev, VIDIOCMCAPTURE, &vid_mmap) == -1) {
-			const char msg[]="mcapture error in proc ";
-			printf("[%d] %s%d: %m\n", cnt->threadnr, msg, getpid());
-			syslog(LOG_ERR, "[%d] %s%d: %m", cnt->threadnr, msg, getpid());
+			motion_log(cnt, LOG_ERR, 1, "mcapture error in proc %d", getpid());
 			sigprocmask (SIG_UNBLOCK, &old, NULL);
-			return (NULL);
+			return (-1);
 		}
 
 		vid_mmap.frame=frame;
 		if (ioctl(dev, VIDIOCSYNC, &vid_mmap.frame) == -1) {
-			const char msg[]="sync error in proc ";
-			printf("[%d] %s%d: %m\n", cnt->threadnr, msg, getpid());
-			syslog(LOG_ERR, "[%d] %s%d: %m", cnt->threadnr, msg, getpid());
+			motion_log(cnt, LOG_ERR, 1, "sync error in proc %d", getpid());
 			sigprocmask (SIG_UNBLOCK, &old, NULL);
 		}
 		
-		pthread_sigmask (SIG_UNBLOCK, &old, NULL);	/*undo the signal blocking*/
+		pthread_sigmask (SIG_UNBLOCK, &old, NULL);        /*undo the signal blocking*/
 	}
 	if (!viddev->v4l_read_img) {
 		switch (viddev->v4l_fmt) {
@@ -430,11 +419,11 @@ static char *v4l_next (struct video_dev *viddev, unsigned char *map, int width,
 		}
 	}
 
-	return map;
+	return 0;
 }
 
-void v4l_set_input (struct video_dev *viddev, unsigned char *map, int width, int height, int input,
-                    int norm, int skip, unsigned long freq, int tuner_number, struct context *cnt)
+void v4l_set_input(struct context *cnt, struct video_dev *viddev, unsigned char *map, int width, int height, int input,
+                    int norm, int skip, unsigned long freq, int tuner_number)
 {
 	int dev=viddev->fd;
 	int i;
@@ -447,8 +436,7 @@ void v4l_set_input (struct video_dev *viddev, unsigned char *map, int width, int
 		if (freq) {
 			vid_tuner.tuner = tuner_number;
 			if (ioctl (dev, VIDIOCGTUNER, &vid_tuner)==-1) {
-				printf("[%d] ioctl (VIDIOCGTUNER): %m\n", cnt->threadnr);
-				syslog(LOG_ERR, "[%d] ioctl (VIDIOCGTUNER): %m", cnt->threadnr);
+				motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGTUNER)");
 			} else {
 				if (vid_tuner.flags & VIDEO_TUNER_LOW) {
 					frequnits=freq*16; /* steps of 1/16 KHz */
@@ -456,8 +444,7 @@ void v4l_set_input (struct video_dev *viddev, unsigned char *map, int width, int
 					frequnits=(freq*10)/625;
 				}
 				if (ioctl(dev, VIDIOCSFREQ, &frequnits)==-1) {
-					printf("[%d] ioctl (VIDIOCSFREQ): %m\n", cnt->threadnr);
-					syslog(LOG_ERR, "[%d] ioctl (VIDIOCSFREQ): %m", cnt->threadnr);
+					motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCSFREQ)");
 					return;
 				}
 			}
@@ -466,19 +453,16 @@ void v4l_set_input (struct video_dev *viddev, unsigned char *map, int width, int
 		vid_chnl.channel = input;
 		
 		if (ioctl (dev, VIDIOCGCHAN, &vid_chnl) == -1) {
-			printf("[%d] ioctl (VIDIOCGCHAN): %m\n", cnt->threadnr);
-			syslog(LOG_ERR, "[%d] ioctl (VIDIOCGCHAN): %m", cnt->threadnr);
+			motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGCHAN)");
 		} else {
-			//DEBUG CODE syslog(LOG_DEBUG, "input: %d", input);
 			vid_chnl.channel = input;
 			vid_chnl.norm = norm;
 			if (ioctl (dev, VIDIOCSCHAN, &vid_chnl) == -1) {
-				printf("[%d] ioctl (VIDIOCSCHAN): %m\n", cnt->threadnr);
-				syslog(LOG_ERR, "[%d] ioctl (VIDIOCSCHAN): %m", cnt->threadnr);
+				motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCSCHAN)");
 				return;
 			}
 		}
-		v4l_picture_controls(viddev, cnt);
+		v4l_picture_controls(cnt, viddev);
 		viddev->input=input;
 		viddev->width=width;
 		viddev->height=height;
@@ -486,10 +470,10 @@ void v4l_set_input (struct video_dev *viddev, unsigned char *map, int width, int
 		viddev->tuner_number=tuner_number;
 		/* skip a few frames if needed */
 		for (i=0; i<skip; i++)
-			v4l_next (viddev, map, width, height, cnt);
+			v4l_next(cnt, viddev, map, width, height);
 	} else {
 		/* No round robin - we only adjust picture controls */
-		v4l_picture_controls(viddev, cnt);
+		v4l_picture_controls(cnt, viddev);
 	}
 }
 
@@ -503,17 +487,13 @@ static int v4l_open_vidpipe(struct context *cnt)
 	struct utsname uts;
 
 	if (uname(&uts) < 0) {
-		const char msg[]="Unable to execute uname: ";
-		printf("[%d] %s%m\n", cnt->threadnr, msg);
-		syslog(LOG_ERR, "[%d] %s%m", cnt->threadnr, msg);
+		motion_log(cnt, LOG_ERR, 1, "Unable to execute uname");
 		return -1;
 	}
 	major = strtok(uts.release, ".");
 	minor = strtok(NULL, ".");
 	if ((major == NULL) || (minor == NULL) || (strcmp(major, "2"))) {
-		const char msg[]="Unable to decipher OS version";
-		printf("[%d] %s\n", cnt->threadnr, msg);
-		syslog(LOG_ERR, "[%d] %s", cnt->threadnr, msg);
+		motion_log(cnt, LOG_ERR, 1, "Unable to decipher OS version");
 		return -1;
 	}
 	if (strcmp(minor, "5") < 0) {
@@ -526,16 +506,25 @@ static int v4l_open_vidpipe(struct context *cnt)
 
 		vloopbacks=fopen("/proc/video/vloopback/vloopbacks", "r");
 		if (!vloopbacks) {
-			const char msg[]="Failed to open '/proc/video/vloopback/vloopbacks': ";
-			printf("[%d] %s%m\n", cnt->threadnr, msg);
-			syslog(LOG_ERR, "[%d] %s%m", cnt->threadnr, msg);
+			motion_log(cnt, LOG_ERR, 1, "Failed to open '/proc/video/vloopback/vloopbacks'");
 			return -1;
 		}
+		
 		/* Read vloopback version*/
-		fgets(buffer, 255, vloopbacks);
+		if (!fgets(buffer, 255, vloopbacks)) {
+			motion_log(cnt, LOG_ERR, 1, "Unable to read vloopback version");
+			return -1;
+		}
+		
 		fprintf(stderr,"\t%s", buffer);
+		
 		/* Read explaination line */
-		fgets(buffer, 255, vloopbacks);
+		
+		if (!fgets(buffer, 255, vloopbacks)) {
+			motion_log(cnt, LOG_ERR, 1, "Unable to read vloopback explanation line");
+			return -1;
+		}
+		
 		while (fgets(buffer, 255, vloopbacks)) {
 			if (strlen(buffer)>1) {
 				buffer[strlen(buffer)-1]=0;
@@ -548,8 +537,8 @@ static int v4l_open_vidpipe(struct context *cnt)
 					sprintf(pipepath, "/dev/%s", input);
 					pipe=open(pipepath, O_RDWR);
 					if (pipe>=0) {
-						fprintf(stderr,"\tInput: /dev/%s\n", input);
-						fprintf(stderr,"\tOutput: /dev/%s\n", output);
+						motion_log(cnt, -1, 0, "\tInput:  /dev/%s", input);
+						motion_log(cnt, -1, 0, "\tOutput: /dev/%s", output);
 						break;
 					}
 				}
@@ -567,9 +556,7 @@ static int v4l_open_vidpipe(struct context *cnt)
 		int tnum;
 
 		if ((dir=opendir(prefix))== NULL) {
-			const char msg[]="Failed to open ";
-			printf("[%d] %s'%s': %m\n", cnt->threadnr, msg, prefix);
-			syslog(LOG_ERR, "[%d] %s'%s': %m", cnt->threadnr, msg, prefix);
+			motion_log(cnt, LOG_ERR, 1, "Failed to open '%s'", prefix);
 			return -1;
 		}
 		while ((dirp=readdir(dir)) != NULL) {
@@ -616,14 +603,13 @@ static int v4l_open_vidpipe(struct context *cnt)
 			}
 		}
 		closedir(dir);
-		if (pipe >= 0) {
-			printf("[%d] Opened input of %s\n", cnt->threadnr, pipepath);
-		}
+		if (pipe >= 0)
+			motion_log(cnt, -1, 0, "Opened input of %s", pipepath);
 	}
 	return pipe;
 }
 
-static int v4l_startpipe (char *devname, int width, int height, int type, struct context *cnt)
+static int v4l_startpipe(struct context *cnt, char *devname, int width, int height, int type)
 {
 	int dev;
 	struct video_picture vid_pic;
@@ -638,32 +624,28 @@ static int v4l_startpipe (char *devname, int width, int height, int type, struct
 		return(-1);
 
 	if (ioctl(dev, VIDIOCGPICT, &vid_pic)== -1) {
-		printf("[%d] ioctl VIDIOCGPICT: %m\n", cnt->threadnr);
-		syslog(LOG_ERR, "[%d] ioctl VIDIOCGPICT: %m", cnt->threadnr);
+		motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGPICT)");
 		return(-1);
 	}
 	vid_pic.palette=type;
 	if (ioctl(dev, VIDIOCSPICT, &vid_pic)== -1) {
-		printf("[%d] ioctl VIDIOCSPICT: %m\n", cnt->threadnr);
-		syslog(LOG_ERR, "[%d] ioctl VIDIOCSPICT: %m", cnt->threadnr);
+		motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCSPICT)");
 		return(-1);
 	}
 	if (ioctl(dev, VIDIOCGWIN, &vid_win)== -1) {
-		printf("[%d] ioctl VIDIOCGWIN: %m\n", cnt->threadnr);
-		syslog(LOG_ERR, "[%d] ioctl VIDIOCGWIN: %m", cnt->threadnr);
+		motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCGWIN)");
 		return(-1);
 	}
 	vid_win.height=height;
 	vid_win.width=width;
 	if (ioctl(dev, VIDIOCSWIN, &vid_win)== -1) {
-		printf("[%d] ioctl VIDIOCSWIN: %m\n", cnt->threadnr);
-		syslog(LOG_ERR, "[%d] ioctl VIDIOCSWIN: %m", cnt->threadnr);
+		motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCSWIN)");
 		return(-1);
 	}
 	return dev;
 }
 
-static int v4l_putpipe (int dev, char *image, int size)
+static int v4l_putpipe (int dev, unsigned char *image, int size)
 {
 	return write(dev, image, size);
 }
@@ -680,10 +662,10 @@ pthread_mutex_t vid_mutex;
 /* structure used for per device locking */
 struct video_dev **viddevs=NULL;
 
-void vid_init(void)
+void vid_init(struct context *cnt)
 {
 	if (!viddevs) {
-		viddevs=mymalloc(sizeof(struct video_dev *));
+		viddevs=mymalloc(cnt, sizeof(struct video_dev *));
 		viddevs[0]=NULL;
 	}
 
@@ -699,7 +681,6 @@ void vid_close(void)
 		while(viddevs[++i]) {
 			close(viddevs[i]->fd);
 		}
-		//fprintf(stderr,"Closing devices ...\n");
 	}
 }
 
@@ -707,13 +688,12 @@ void vid_cleanup(void)
 {
 	int i=-1;
 	if (viddevs) {
-		while(viddevs[++i]){
+		while(viddevs[++i]) {
 			munmap(viddevs[i]->v4l_buffers[0],viddevs[i]->size_map);
 			free(viddevs[i]);
 		}
 		free(viddevs);
 		viddevs=NULL;
-		//fprintf(stderr,"Cleaning viddevs ...\n");
 	}
 }
 #endif /*WITHOUT_V4L*/
@@ -776,8 +756,8 @@ int vid_start (struct context *cnt)
 			}
 		}
 
-		viddevs=myrealloc(viddevs, sizeof(struct video_dev *)*(i+2), "vid_start");
-		viddevs[i]=mymalloc(sizeof(struct video_dev));
+		viddevs=myrealloc(cnt, viddevs, sizeof(struct video_dev *)*(i+2), "vid_start");
+		viddevs[i]=mymalloc(cnt, sizeof(struct video_dev));
 		memset(viddevs[i], 0, sizeof(struct video_dev));
 		viddevs[i+1]=NULL;
 
@@ -786,8 +766,8 @@ int vid_start (struct context *cnt)
 
 		dev=open(conf->video_device, O_RDWR);
 		if (dev <0) {
-			printf("[%d] Failed to open video device %s\n", cnt->threadnr, conf->video_device);
-			syslog(LOG_ERR, "[%d] Failed to open video device %s: %m", cnt->threadnr, conf->video_device);
+			motion_log(cnt, LOG_ERR, 1, "Failed to open video device %s", conf->video_device);
+			motion_log(cnt, LOG_ERR, 0, "Motion Exits");
 			exit(1);
 		}
 
@@ -810,7 +790,7 @@ int vid_start (struct context *cnt)
 
 		viddevs[i]->v4l_fmt=VIDEO_PALETTE_YUV420P;
 
-		if (!v4l_start (viddevs[i], width, height, input, norm, frequency, tuner_number, cnt)) {
+		if (!v4l_start (cnt, viddevs[i], width, height, input, norm, frequency, tuner_number)) {
 			pthread_mutex_unlock(&vid_mutex);
 			return -1;
 		}
@@ -835,15 +815,27 @@ int vid_start (struct context *cnt)
 	return dev;
 }
 
-char *vid_next (struct context *cnt, unsigned char *map)
+
+/**
+ * vid_next fetches a video frame from a either v4l device or netcam
+ * Parameters:
+ *     cnt        Pointer to the context for this thread
+ *     map        Pointer to the buffer in which the function puts the new image
+ *
+ * Returns
+ *     0          Success
+ *    -1          Fatal V4L error
+ *    -2          Fatal Netcam error
+ *     1          Non fatal V4L error (not implemented)
+ *     2          Non fatal Netcam error
+ */
+int vid_next(struct context *cnt, unsigned char *map)
 {
 	struct config *conf=&cnt->conf;
-	char *ret=NULL;
+	int ret = -1;
 
 	if (conf->netcam_url) {
-		int retries=0;
-		while ((!cnt->finish) && (!ret) && (retries++<100))
-			ret = netcam_next(cnt, map);
+		ret = netcam_next(cnt, map);
 		return ret;
 	}
 #ifndef WITHOUT_V4L
@@ -861,7 +853,7 @@ char *vid_next (struct context *cnt, unsigned char *map)
 				break;
 
 		if (!viddevs[i])
-			return NULL;
+			return -1;
 
 		if (viddevs[i]->owner!=cnt->threadnr) {
 			pthread_mutex_lock(&viddevs[i]->mutex);
@@ -870,9 +862,9 @@ char *vid_next (struct context *cnt, unsigned char *map)
 			cnt->switched=1;
 		}
 
-		v4l_set_input (viddevs[i], map, width, height, conf->input, conf->norm,
-		               conf->roundrobin_skip, conf->frequency, conf->tuner_number, cnt);
-		ret=v4l_next (viddevs[i], map, width, height, cnt);
+		v4l_set_input(cnt, viddevs[i], map, width, height, conf->input, conf->norm,
+		               conf->roundrobin_skip, conf->frequency, conf->tuner_number);
+		ret = v4l_next(cnt, viddevs[i], map, width, height);
 
 		if (--viddevs[i]->frames <= 0) {
 			viddevs[i]->owner=-1;
@@ -881,7 +873,7 @@ char *vid_next (struct context *cnt, unsigned char *map)
 	
 		if(cnt->rotate_data.degrees > 0) {
 			/* rotate the image as specified */
-			rotate_map(map, cnt);
+			rotate_map(cnt, map);
 		}
 	}
 #endif /*WITHOUT_V4L*/
@@ -889,12 +881,12 @@ char *vid_next (struct context *cnt, unsigned char *map)
 }
 
 #ifndef WITHOUT_V4L
-int vid_startpipe (char *devname, int width, int height, int type, struct context *cnt)
+int vid_startpipe (struct context *cnt, char *devname, int width, int height, int type)
 {
-	return v4l_startpipe (devname, width, height, type, cnt);
+	return v4l_startpipe(cnt, devname, width, height, type);
 }
 
-int vid_putpipe (int dev, char *image, int size)
+int vid_putpipe (int dev, unsigned char *image, int size)
 {
 	return v4l_putpipe (dev, image, size);
 }
