@@ -21,7 +21,7 @@
 #include "sys/ioctl.h"
 
 /* Hack from xawtv 4.x */
-                                                                                                                             
+
 #define VIDEO_NONE           0
 #define VIDEO_RGB08          1  /* bt848 dithered */
 #define VIDEO_GRAY           2
@@ -72,20 +72,18 @@ static const struct camparam_st {
 #define BRIGHT 0
 #define CONTR  1
 #define CHROMA 2
-                                                                                                                             
+
 #define NTSC_MAX_X        640
 #define NTSC_MAX_Y        480
 #define PAL_MAX_X         768
 #define PAL_MAX_Y         576
-#define PAL		1
-#define NTSC		2	
+#define PAL                 1
+#define NTSC                2
  
-#define FBTTV_MAX_WIDTH    MAX(NTSC_MAX_X, PAL_MAX_X)
-#define FBTTV_MAX_HEIGHT   MAX(NTSC_MAX_Y, PAL_MAX_Y)
-#define FBTTV_MIN_WIDTH    2
-#define FBTTV_MIN_HEIGHT   2
-
-extern int errno;
+#define FBTTV_MAX_WIDTH     MAX(NTSC_MAX_X, PAL_MAX_X)
+#define FBTTV_MAX_HEIGHT    MAX(NTSC_MAX_Y, PAL_MAX_Y)
+#define FBTTV_MIN_WIDTH     2
+#define FBTTV_MIN_HEIGHT    2
 
 
 /* Not tested yet */
@@ -159,8 +157,7 @@ void rgb24toyuv420p(unsigned char *map, unsigned char *cap_map, int width, int h
 			v++;
 		}
 
-		if ((loop & 1) == 1)
-		{
+		if ((loop & 1) == 1) {
 			u-=width/2;
 			v-=width/2;
 		}
@@ -176,12 +173,12 @@ void rgb24toyuv420p(unsigned char *map, unsigned char *cap_map, int width, int h
 static int camparam_normalize( int param, int cfg_value, int *ioctl_val ) 
 {
 	int val;
-                                                                                                                             
+
 	cfg_value = MIN( CamParams[ param ].max, MAX( CamParams[ param ].min, cfg_value ) ); 
 	val = (cfg_value - CamParams[ param ].min ) /
-		(CamParams[ param ].range + 0.01) * CamParams[param].drv_range + CamParams[param].drv_min;
+	      (CamParams[ param ].range + 0.01) * CamParams[param].drv_range + CamParams[param].drv_min;
 	val = MAX( CamParams[ param ].min,
-		MIN( CamParams[ param ].drv_min + CamParams[ param ].drv_range-1,val ));
+	      MIN( CamParams[ param ].drv_min + CamParams[ param ].drv_range-1,val ));
 	*ioctl_val = val;
 	return cfg_value;
 }
@@ -190,15 +187,14 @@ static int camparam_normalize( int param, int cfg_value, int *ioctl_val )
 static int set_chroma( struct video_dev *viddev, int new_chroma ) 
 {
 	int ioctlval;
-                                                                                                                             
+
 	new_chroma = camparam_normalize( CHROMA, new_chroma, &ioctlval );
-                                                                                                                             
+
 	if( ioctl( viddev->fd_tuner, BT848_SCSAT, &ioctlval ) < 0 ) {
-		printf( "Error setting CHROMA: %s\n", strerror( errno ));
-		syslog( LOG_ERR, "Error setting CHROMA: %s", strerror( errno ));
+		motion_log(cnt, LOG_ERR, 1, "Error setting CHROMA");
 		return -1;
 	}
-                                                                                                                             
+
 	viddev->chroma = new_chroma;
 
 	return 0;
@@ -207,15 +203,14 @@ static int set_chroma( struct video_dev *viddev, int new_chroma )
 static int set_contrast( struct video_dev *viddev, int new_contrast ) 
 {
 	int ioctlval;
-  
+
 	new_contrast = camparam_normalize( CONTR, new_contrast, &ioctlval );
-  
+
 	if( ioctl( viddev->fd_tuner, BT848_SCONT, &ioctlval ) < 0 ) {
-		printf( "Error setting contrast: %s\n",strerror( errno ));
-		syslog( LOG_ERR, "Error setting contrast: %s",strerror( errno ));
+		motion_log(cnt, LOG_ERR, 1, "Error setting contrast");
 		return -1;
 	}
-  
+
 	viddev->contrast = new_contrast;
 
 	return 0;
@@ -227,17 +222,15 @@ static int set_contrast( struct video_dev *viddev, int new_contrast )
 static int set_channel( struct video_dev *viddev, int new_channel ) 
 {
 	int ioctlval;
-                                                                                                                             
+
 	ioctlval = new_channel;
 	if( ioctl( viddev->fd_tuner, TVTUNER_SETCHNL, &ioctlval ) < 0 ) {
-		printf( "Error channel->%d : %s\n", ioctlval, strerror( errno ) );
-		syslog( LOG_ERR, "Error channel->%d : %s", ioctlval, strerror( errno ) );
+		motion_log(cnt, LOG_ERR, 1, "Error channel %d",ioctlval);
 		return -1;
 	} else {
-		printf("channel set to %d\n", ioctlval);
-		syslog(LOG_ERR, "channel set to %d", ioctlval);
+		motion_log(cnt, LOG_DEBUG, 0, "channel set to %d",ioctlval);
 	}
-                                                                                                                             
+
 	viddev->channel = new_channel;
  
 	return 0;
@@ -246,7 +239,7 @@ static int set_channel( struct video_dev *viddev, int new_channel )
 
 /* set frequency to tuner */
 
-static int set_freq (struct video_dev *viddev,unsigned long freq, struct context *cnt)
+static int set_freq(struct context *cnt, struct video_dev *viddev, unsigned long freq)
 {
 	int tuner_fd = viddev->fd_tuner;
 	int old_audio;
@@ -254,23 +247,20 @@ static int set_freq (struct video_dev *viddev,unsigned long freq, struct context
 	/* HACK maybe not need it , but seems that is needed to mute before changing frequency */
 
 	if ( ioctl( tuner_fd, BT848_GAUDIO, &old_audio ) < 0 ) {
-		printf("[%d] BT848_GAUDIO\n", cnt->threadnr);
-		syslog( LOG_ERR , "[%d] BT848_GAUDIO", cnt->threadnr);
+		motion_log(cnt, LOG_ERR, 1, "BT848_GAUDIO");
 		return -1;
 	}
 	
 	if (ioctl(tuner_fd, TVTUNER_SETFREQ, &freq) < 0){
-		printf("[%d] Tuning (TVTUNER_SETFREQ) failed, reason [%s] freq [%lu]\n", cnt->threadnr, strerror(errno),freq);
-		syslog(LOG_ERR,"[%d] Tuning (TVTUNER_SETFREQ) failed, reason [%s] freq [%lu]", cnt->threadnr, strerror(errno),freq);
-		return -1;	
+		motion_log(cnt, LOG_ERR, 1, "Tuning (TVTUNER_SETFREQ) failed , freq [%lu]",freq);
+		return -1;
 	}
 
 	old_audio &= AUDIO_MUTE;
 	if ( old_audio ){
 		old_audio = AUDIO_MUTE;
 		if ( ioctl(tuner_fd , BT848_SAUDIO, &old_audio ) < 0 ) {
-			printf ( "[%d] BT848_SAUDIO [%i]\n", cnt->threadnr, old_audio );
-			syslog ( LOG_ERR,"[%d] BT848_SAUDIO [%i]", cnt->threadnr, old_audio );
+			motion_log(cnt, LOG_ERR, 1, "BT848_SAUDIO %i",old_audio);
 			return -1;
 		}
 	}
@@ -287,34 +277,31 @@ static int set_freq (struct video_dev *viddev,unsigned long freq, struct context
 	VBI ?! (METEOR_INPUT_DEV_SVIDEO)
 */
 
-static int set_input( struct video_dev *viddev , int input , struct context *cnt)
+static int set_input(struct context *cnt, struct video_dev *viddev, int input)
 {
 	int actport;
 	int portdata[] = { METEOR_INPUT_DEV0, METEOR_INPUT_DEV1,
-			METEOR_INPUT_DEV2, METEOR_INPUT_DEV3,
-			METEOR_INPUT_DEV_SVIDEO  };
-                                                                                                                             
-	if( input >= array_elem( portdata ) ){
-		printf( "[%d] Port %d out of range (0-4)\n", cnt->threadnr, input );
-		syslog( LOG_ERR, "[%d] Port %d out of range (0-4)", cnt->threadnr, input );
+	                 METEOR_INPUT_DEV2, METEOR_INPUT_DEV3,
+	                 METEOR_INPUT_DEV_SVIDEO  };
+
+	if( input >= array_elem( portdata ) ) {
+		motion_log(cnt, LOG_WARNING, 0, "Channel Port %d out of range (0-4)",input);
 		input = IN_DEFAULT;
 	}
-														     
+
 	actport = portdata[ input ];
-	if( ioctl( viddev->fd_bktr, METEORSINPUT, &actport ) < 0 ){
+	if( ioctl( viddev->fd_bktr, METEORSINPUT, &actport ) < 0 ) {
 		if( input != IN_DEFAULT ) {
-			printf("[%d] Port %d invalid -- Trying default of %d\n",cnt->threadnr, input, IN_DEFAULT );
-			syslog( LOG_ERR, "[%d] Port %d invalid -- Trying default of %d",cnt->threadnr, input, IN_DEFAULT );
+			motion_log(cnt, LOG_WARNING, 0,
+			           "METEORSINPUT %d invalid - Trying default %d ", input, IN_DEFAULT );
 			input = IN_DEFAULT;
 			actport = portdata[ input ];
 			if( ioctl( viddev->fd_bktr, METEORSINPUT, &actport ) < 0 ) {
-				printf( "[%d] Port %d init: %s\n", cnt->threadnr, input, strerror( errno ));
-				syslog( LOG_ERR, "[%d] Port %d init: %s", cnt->threadnr, input, strerror( errno ));
+				motion_log(cnt, LOG_ERR, 1, "METEORSINPUT %d init", input);
 				return -1;
 			}
 		} else {
-			printf( "[%d] Port %d init: %s\n", cnt->threadnr, input , strerror( errno ));
-			syslog( LOG_ERR, "[%d] Port %d init: %s", cnt->threadnr, input , strerror( errno ));
+			motion_log(cnt, LOG_ERR, 1, "METEORSINPUT  %d init",input);
 			return -1;
 		}
 	}
@@ -322,45 +309,43 @@ static int set_input( struct video_dev *viddev , int input , struct context *cnt
 	return 0;
 }
 
-static int set_geometry( struct video_dev *viddev, int width , int height , int format, struct context *cnt)
+static int set_geometry(struct context *cnt, struct video_dev *viddev, int width , int height , int format)
 {
 	struct meteor_geomet geom;
-														     
+
 	geom.columns = width;
 	geom.rows = height;
 	geom.oformat = METEOR_GEO_YUV_422 | METEOR_GEO_YUV_12;
 	geom.oformat |= METEOR_GEO_EVEN_ONLY;	
 	geom.frames  = 1;
-                                                                                                                          
-  	if( ioctl( viddev->fd_bktr, METEORSETGEO, &geom ) < 0 ) {
-		printf( "[%d] Couldn't set the geometry: %s\n", cnt->threadnr, strerror( errno ) );
-		syslog( LOG_ERR, "[%d] Couldn't set the geometry: %s", cnt->threadnr, strerror( errno ) );
+
+	if( ioctl( viddev->fd_bktr, METEORSETGEO, &geom ) < 0 ) {
+		motion_log(cnt, LOG_ERR, 1, "Couldn't set the geometry");
 		return -1;
-  	}
-                                                                                                                             
-  	return 0;
+	}
+
+	return 0;
 }
 
 /*
    set input format ( NTSC , PAL , SECAM , etc ... ) not all supported yet FIXME
 */
 
-static int set_input_format(struct video_dev *viddev, int newformat, struct context *cnt) 
+static int set_input_format(struct context *cnt, struct video_dev *viddev, int newformat) 
 {
 	int format;
 	int input_format[] = { NORM_PAL, NORM_NTSC, NORM_SECAM };
  
-	if( newformat >= array_elem( input_format ) ){
-		printf( "[%d] Input format %d out of range (0-2)\n", cnt->threadnr, newformat );
-		syslog( LOG_ERR, "[%d] Input format %d out of range (0-2)", cnt->threadnr, newformat );
+	if( newformat >= array_elem( input_format ) ) {
+		motion_log(cnt, LOG_WARNING, 0, "Input format %d out of range (0-2)",newformat );
 		format = NORM_DEFAULT;newformat = 0;
-	}else format = input_format[newformat]; 
+	} else
+		format = input_format[newformat]; 
 
 	/* FIXME should be BT848SFMT for new BKTR INTERFACES */
 
 	if( ioctl( viddev->fd_bktr, METEORSFMT, &format ) < 0 ) {
-		printf( "[%d] Couldn't set the input format : %s\n", cnt->threadnr, strerror( errno ) );
-		syslog( LOG_ERR, "[%d] Couldn't set the input format : %s", cnt->threadnr, strerror( errno ) );
+		motion_log(cnt, LOG_ERR, 1, "METEORSFMT Couldn't set the input format");
 		return -1;
 	}
 	return 0;
@@ -370,15 +355,14 @@ static int set_input_format(struct video_dev *viddev, int newformat, struct cont
 static int set_brightness( struct video_dev *viddev, int new_bright ) 
 {
 	int ioctlval;
-                                                                                                                             
+
 	new_bright = camparam_normalize( BRIGHT, new_bright, &ioctlval );
 	if( ioctl( viddev->fd_tuner, BT848_SBRIG, &ioctlval ) < 0 ) {
-		printf( "Error brightness->%d : %s\n", ioctlval,strerror( errno ) );
-		syslog( LOG_ERR, "Error brightness->%d : %s", ioctlval,strerror( errno ) );
+		motion_log(cnt, LOG_ERR, 1, " BT848_SBRIG brightness %d",ioctlval);
 		return -1;
 	}
 	viddev->brightness = new_bright;
-                 
+
 	return 0;
 }
 
@@ -395,76 +379,73 @@ statict int setup_pixelformat( int bktr )
 		if( ioctl( bktr, METEORGSUPPIXFMT, &p ) < 0 ){
 			if( errno == EINVAL )
 				break;
-			printf("Error getting pixformat %d: %s\n", i,strerror( errno ) );
-			syslog(LOG_ERR, "Error getting pixformat %d: %s", i,strerror( errno ) );
+			motion_log(cnt, LOG_ERR, 1, "METEORGSUPPIXFMT getting pixformat %d",i);	
 			return -1;
 		}
-    
+
 
 	// Hack from xawtv 4.x 
-                                                                                                                             
+
 	switch ( p.type ){
 		case METEOR_PIXTYPE_RGB:
-			printf("setup_pixelformat METEOR_PIXTYPE_RGB\n");
+			motion_log(cnt, -1, 0, "setup_pixelformat METEOR_PIXTYPE_RGB");
 			switch(p.masks[0]) {
 				case 31744: // 15 bpp 
 					format = p.swap_bytes ? VIDEO_RGB15_LE : VIDEO_RGB15_BE;
-					printf("setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_RGB15\n");
+					motion_log(cnt, -1, 0, "setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_RGB15");
 				break;
 				case 63488: // 16 bpp 
 					format = p.swap_bytes ? VIDEO_RGB16_LE : VIDEO_RGB16_BE;
-					printf("setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_RGB16\n");
+					motion_log(cnt, -1, 0, "setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_RGB16");
 				break;
 				case 16711680: // 24/32 bpp 
 					if (p.Bpp == 3 && p.swap_bytes == 1) {
 						format = VIDEO_BGR24;
-						printf("setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_BGR24\n");
+						motion_log(cnt, -1, 0, "setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_BGR24");
 					} else if (p.Bpp == 4 && p.swap_bytes == 1 && p.swap_shorts == 1) {
 						format = VIDEO_BGR32;
-						printf("setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_BGR32\n");
+						motion_log(cnt, -1, 0, "setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_BGR32");
 						} else if (p.Bpp == 4 && p.swap_bytes == 0 && p.swap_shorts == 0) {
 							format = VIDEO_RGB32;
-							printf("setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_RGB32\n");
+							motion_log(cnt, -1, 0, "setup_pixelformat METEOR_PIXTYPE_RGB VIDEO_RGB32");
 						}
 					}
 				break;
 				case METEOR_PIXTYPE_YUV:
-					printf("setup_pixelformat METEOR_PIXTYPE_YUV\n");
 					format = VIDEO_YUV422P;
+					motion_log(cnt, -1, 0, "setup_pixelformat METEOR_PIXTYPE_YUV");
 				break;
 				case METEOR_PIXTYPE_YUV_12:
-					printf("setup_pixelformat METEOR_PIXTYPE_YUV_12\n");
 					format = VIDEO_YUV422P;
+					motion_log(cnt, -1, 0, "setup_pixelformat METEOR_PIXTYPE_YUV_12");
 					break;
 				case METEOR_PIXTYPE_YUV_PACKED:
-					printf("setup_pixelformat METEOR_PIXTYPE_YUV_PACKED\n");
 					format = VIDEO_YUV422P;
+					motion_log(cnt, -1, 0, "setup_pixelformat METEOR_PIXTYPE_YUV_PACKED");
 				break;
 	
 			}
-                                                                                                           
+
 			if( p.type == METEOR_PIXTYPE_RGB && p.Bpp == 3 ){
 				// Found a good pixeltype -- set it up 
 				if( ioctl( bktr, METEORSACTPIXFMT, &i ) < 0 ){
-					printf( "Error setting pixformat METEOR_PIXTYPE_RGB Bpp == 3 : %s\n",strerror( errno ));
-					syslog( LOG_ERR, "Error setting pixformat METEOR_PIXTYPE_RGB Bpp == 3 : %s",strerror( errno ));
+					motion_log(cnt, LOG_WARNING, 1, "METEORSACTPIXFMT etting pixformat METEOR_PIXTYPE_RGB Bpp == 3");
 				// Not immediately fatal 
-				} //else return 0;
-				printf("input format METEOR_PIXTYPE_RGB [%i]\n",i);
+				}
+				motion_log(cnt, LOG_DEBUG, 0, "input format METEOR_PIXTYPE_RGB %i",i);
 				format=i;
 			}
 
 			if( p.type == METEOR_PIXTYPE_YUV_PACKED ){
 				// Found a good pixeltype -- set it up
 				if( ioctl( bktr, METEORSACTPIXFMT, &i ) < 0 ){
-					printf( "Error setting pixformat METEOR_PIXTYPE_YUV_PACKED: %s\n", strerror( errno ));
-					syslog( LOG_ERR, "Error setting pixformat METEOR_PIXTYPE_YUV_PACKED: %s", strerror( errno ));
+					motion_log(cnt, LOG_WARNING, 1, "METEORSACTPIXFMT setting pixformat METEOR_PIXTYPE_YUV_PACKED");
 				// Not immediately fatal
-				} //else return 0;
-				printf("input format METEOR_PIXTYPE_YUV_PACKED [%i]\n",i);
+				} 
+				motion_log(cnt, LOG_DEBUG, 0, "input format METEOR_PIXTYPE_YUV_PACKED %i",i);
 				format=i;
 			}
-      
+
 		}
 
 	return format;
@@ -487,7 +468,7 @@ statict int setup_pixelformat( int bktr )
  - set_capture_mode
 
 */
-static char *v4l_start (struct video_dev *viddev, int width, int height, int input, int norm, unsigned long freq, struct context *cnt)
+static char *v4l_start(struct context *cnt, struct video_dev *viddev, int width, int height, int input, int norm, unsigned long freq)
 {
 	int dev_bktr=viddev->fd_bktr;
 	//int dev_tunner=viddev->fd_tuner;
@@ -497,31 +478,30 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 	int single  = METEOR_CAP_SINGLE;
 	char *map;
 
-	if ( ((freq <= 0) && (input == IN_TV)) || ( set_input(viddev,input,cnt) == -1) ){
-		 printf("[%d] Error!  Frequency [%lu] Source input [%i]\n",cnt->threadnr,freq,input);
-		 syslog(LOG_ERR,"[%d] Error!  Frequency [%lu] Source input [%i]",cnt->threadnr,freq,input);
-		 return (NULL);
+	if ( ((freq <= 0) && (input == IN_TV)) || ( set_input(cnt, viddev, input) == -1) ) {
+		motion_log(cnt, LOG_ERR, 1, "Frequency [%lu] Source input [%i]",freq,input);
+		return (NULL);
 	}
  
 	/* if we have choose the tuner is needed to setup the frequency */
-	if ( input == IN_TV ){
-		if (set_freq (viddev,freq, cnt) == -1){
+	if ( input == IN_TV ) {
+		if (set_freq(cnt, viddev, freq) == -1) {
 			return (NULL);
 		}
 	}
 	
 	/* FIXME if we set as input tuner , we need to set option for tuner not for bktr */
 
-	if ( set_input_format(viddev,norm,cnt) == -1 ){
+	if ( set_input_format(cnt, viddev, norm) == -1 ) {
 		return (NULL);
 	}
 
-	if ( set_geometry(viddev,width,height,norm, cnt) == -1){
+	if (set_geometry(cnt, viddev, width, height, norm) == -1) {
 		return (NULL);
-        }
+	}
 
 /*
-	if ( setup_pixelformat(viddev) == -1){
+	if ( setup_pixelformat(viddev) == -1) {
 		return (NULL);
 	}
 
@@ -530,14 +510,14 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 	set_contrast(viddev,CONTR);
 */
 
-	if (freq != 0){
+	if (freq != 0) {
 	/*
 	 TODO missing implementation
 		set_channelset(viddev);
 		set_channel(viddev);
-		if (set_freq (viddev,freq, cnt) == -1){
-                        return (NULL);
-                }
+		if (set_freq (cnt, viddev, freq) == -1) {
+			return (NULL);
+		}
 	*/
 	}
 
@@ -550,12 +530,12 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 	viddev->v4l_bufsize = (((width*height*3/2)) * sizeof(unsigned char *));
 	viddev->v4l_fmt = VIDEO_PALETTE_YUV420P;
 
-        map = mmap((caddr_t)0,viddev->v4l_bufsize,PROT_READ|PROT_WRITE,MAP_SHARED, dev_bktr, (off_t)0);
+	map = mmap((caddr_t)0,viddev->v4l_bufsize,PROT_READ|PROT_WRITE,MAP_SHARED, dev_bktr, (off_t)0);
 
 	if ((unsigned char *)-1 == (unsigned char *)map) {
-		printf("[%d] mmap failed [%s]\n",cnt->threadnr,strerror(errno));
-                return (NULL);
-        }
+		motion_log(cnt, LOG_ERR, 1, "mmap failed");
+		return (NULL);
+	}
 
 	/* FIXME double buffer */ 
 	if (0) {
@@ -568,47 +548,54 @@ static char *v4l_start (struct video_dev *viddev, int width, int height, int inp
 		viddev->v4l_maxbuffer=1;
 	}
 
-	viddev->v4l_curbuffer=0;       
-                                                                                                             
-	// settle
-	sleep(1); 
-	
-	/* capture */	
+	viddev->v4l_curbuffer=0;
+
+	// settle , sleep(1) replaced
+	SLEEP(1,0)
+
+	/* capture */
 	if (ioctl(dev_bktr, METEORCAPTUR, &single) < 0){
-		printf( "[%d] Error capturing: %s\n",
-                       cnt->threadnr, strerror( errno ));
-		syslog( LOG_ERR, "[%d] Error capturing: %s",
-                       cnt->threadnr, strerror( errno ));
+		motion_log(cnt, LOG_ERR, 1, "METEORCAPTUR Error capturing");
 	}
  	
 	
 	/* Palete Color space */
 	/* FIXME*/
 	switch (viddev->v4l_fmt) {
-                case VIDEO_PALETTE_YUV420P:
-			printf("[%d] VIDEO_PALETTE_YUV420P palette setting bufsize \n",cnt->threadnr);
-                        viddev->v4l_bufsize=(width*height*3)/2;
-                        break;
-                case VIDEO_PALETTE_YUV422:
-                        viddev->v4l_bufsize=(width*height*2);
-                        break;
-                case VIDEO_PALETTE_RGB24:
-                        viddev->v4l_bufsize=(width*height*3);
-                        break;
-                case VIDEO_PALETTE_GREY:
-                        viddev->v4l_bufsize=width*height;
-                        break;
-        }
+		case VIDEO_PALETTE_YUV420P:
+			viddev->v4l_bufsize=(width*height*3)/2;
+			motion_log(cnt, -1, 0, "VIDEO_PALETTE_YUV420P palette setting bufsize");
+			break;
+		case VIDEO_PALETTE_YUV422:
+			viddev->v4l_bufsize=(width*height*2);
+			break;
+		case VIDEO_PALETTE_RGB24:
+			viddev->v4l_bufsize=(width*height*3);
+			break;
+		case VIDEO_PALETTE_GREY:
+			viddev->v4l_bufsize=width*height;
+			break;
+	}
 
 	return map;
 }
 
 
-/*
-  Read the next image from device 
-*/
-
-static char *v4l_next (struct video_dev *viddev, char *map, int width, int height, struct context *cnt)
+/**
+ * v4l_next fetches a video frame from a v4l device
+ * Parameters:
+ *     cnt        Pointer to the context for this thread
+ *     viddev     Pointer to struct containing video device handle
+ *     map        Pointer to the buffer in which the function puts the new image
+ *     width      Width of image in pixels
+ *     height     Height of image in pixels
+ *
+ * Returns
+ *     0          Success
+ *    -1          Fatal error
+ *     1          Non fatal error (not implemented)
+ */
+int v4l_next(struct context *cnt, struct video_dev *viddev, char *map, int width, int height)
 {
 	int dev_bktr=viddev->fd_bktr;
 	char *cap_map=NULL;
@@ -618,8 +605,10 @@ static char *v4l_next (struct video_dev *viddev, char *map, int width, int heigh
 
 	if (viddev->v4l_read_img) {
 	/* use read to get capture the image if mmap not supported */	
-		if (read(dev_bktr, map, viddev->v4l_bufsize) != viddev->v4l_bufsize)
-			return NULL;
+		if (read(dev_bktr, map, viddev->v4l_bufsize) != viddev->v4l_bufsize) {
+			motion_log(cnt, LOG_ERR, 0, "capturing frame");
+			return -1;
+		}	
 	} else {
 	/* Allocate a new mmap buffer */
 		/* Block signals during IOCTL */
@@ -636,19 +625,19 @@ static char *v4l_next (struct video_dev *viddev, char *map, int width, int heigh
 		if (viddev->v4l_curbuffer >= viddev->v4l_maxbuffer)
 			viddev->v4l_curbuffer=0;
 
-		 /* capture */
-        	if (ioctl(dev_bktr, METEORCAPTUR, &single) < 0){
-                	printf( "[%d] Error capturing in proc %d: %s\n",cnt->threadnr,getpid(),strerror( errno ));
-                	syslog( LOG_ERR, "[%d] Error capturing in proc %d: %s",cnt->threadnr,getpid(),strerror( errno ));
+		/* capture */
+		if (ioctl(dev_bktr, METEORCAPTUR, &single) < 0) {
+			motion_log(cnt, LOG_ERR, 1, "Error capturing");
 			sigprocmask (SIG_UNBLOCK, &old, NULL);
-			return (NULL);
-        	}
+			return (-1);
+		}
 
 		pthread_sigmask (SIG_UNBLOCK, &old, NULL);	/*undo the signal blocking*/
 	}
 
-	if (!viddev->v4l_read_img) {
-		switch (viddev->v4l_fmt) {
+	if (!viddev->v4l_read_img) 
+	{
+		switch (viddev->v4l_fmt){
 			case VIDEO_PALETTE_RGB24:
 				rgb24toyuv420p(map, cap_map, width, height);
 				break;
@@ -660,47 +649,43 @@ static char *v4l_next (struct video_dev *viddev, char *map, int width, int heigh
 		}
 	}
 	
-	return map;
+	return 0;
 }
 
 
 /* set input & freq if needed FIXME not allowed use Tuner yet */
 
-void v4l_set_input (struct video_dev *viddev, char *map, int width, int height, int input, int norm, int skip, unsigned long freq, struct context *cnt)
+void v4l_set_input(struct context *cnt, struct video_dev *viddev, char *map, int width, int height,
+                    int input, int norm, int skip, unsigned long freq)
 {
 	int i;
 	unsigned long frequnits = freq;
 
 
-	if (input != viddev->input || width != viddev->width || height!=viddev->height || freq!=viddev->freq) {
-		printf("[%d] v4l_set_input really needed ?\n",cnt->threadnr);
-		syslog(LOG_ERR, "[%d] v4l_set_input really needed ?",cnt->threadnr);
+	if (input != viddev->input || width != viddev->width || height!=viddev->height || freq!=viddev->freq){ 
+		motion_log(cnt, LOG_WARNING, 0, "v4l_set_input really needed ?");
 
-		if ( set_input(viddev,input,cnt) == -1){
+		if (set_input(cnt, viddev, input) == -1)
 			return;
-		}
 
-        	if ( set_input_format(viddev,norm,cnt) == -1 ){
+		if (set_input_format(cnt, viddev, norm) == -1 )
 			return;
-		}
 		
-		if (( input == IN_TV ) && (frequnits > 0)){
-			if (set_freq (viddev,freq, cnt) == -1){
+		if (( input == IN_TV ) && (frequnits > 0)) {
+			if (set_freq (cnt, viddev, freq) == -1)
 				return ;
-			}
 		}
- 
-		/* FIXME
-        	if ( setup_pixelformat(viddev) == -1){
-			printf("ioctl (VIDIOCSFREQ): %m\n");
-			syslog(LOG_ERR, "ioctl (VIDIOCSFREQ): %m");
+
+		// FIXME
+		/*
+		if ( setup_pixelformat(viddev) == -1) {
+			motion_log(cnt, LOG_ERR, 1, "ioctl (VIDIOCSFREQ)");
 			return;
-       		}
+		}
 		*/
 
-        	if ( set_geometry(viddev,width,height,norm, cnt) == -1){
+		if (set_geometry(cnt, viddev, width, height, norm) == -1)
 			return;
-		}
 		
 		viddev->input=input;
 		viddev->width=width;
@@ -708,9 +693,8 @@ void v4l_set_input (struct video_dev *viddev, char *map, int width, int height,
 		viddev->freq=freq;
 
 		/* skip a few frames if needed */
-		for (i=0; i<skip; i++){
-			v4l_next (viddev, map, width, height, cnt);
-		}
+		for (i=0; i<skip; i++)
+			v4l_next(cnt, viddev, map, width, height);
 	}
 }
 
@@ -733,10 +717,10 @@ pthread_mutex_t vid_mutex;
 /* structure used for per device locking */
 struct video_dev **viddevs=NULL;
 
-void vid_init(void)
+void vid_init(struct context *cnt)
 {
-	if (!viddevs) {
-		viddevs=mymalloc(sizeof(struct video_dev *));
+	if (!viddevs) { 
+		viddevs=mymalloc(cnt, sizeof(struct video_dev *));
 		viddevs[0]=NULL;
 	}
 
@@ -749,13 +733,13 @@ void vid_close(void)
 	int i=-1;
 //	int stopcap=0;
 
-	if (viddevs) {
-		while(viddevs[++i]) {
-		/*	stopcap = METEOR_CAP_STOP_CONT;
-  			if( ioctl( viddevs[++i]->fd_bktr, METEORCAPTUR, &stopcap ) < 0 )
-    			printf("vid_close: %s\n", strerror( errno ));
-    			syslog(LOG_ERR, "vid_close: %s", strerror( errno ));
-                */
+	if (viddevs){ 
+		while(viddevs[++i]){
+		/*
+			stopcap = METEOR_CAP_STOP_CONT;
+			if( ioctl( viddevs[++i]->fd_bktr, METEORCAPTUR, &stopcap ) < 0 )
+				motion_log(cnt,LOG_ERR , 1, "vid_close METEORCAPTUR");	
+		*/
 			close(viddevs[i]->fd_bktr);
 			close(viddevs[i]->fd_tuner);
 		}
@@ -765,7 +749,7 @@ void vid_close(void)
 void vid_cleanup(void)
 {
 	int i=-1;
-	if (viddevs) {
+	if (viddevs){ 
 		while(viddevs[++i]){
 			munmap(viddevs[i]->v4l_buffers[0],viddevs[i]->v4l_bufsize);
 			free(viddevs[i]);
@@ -778,10 +762,10 @@ void vid_cleanup(void)
 #endif /*WITHOUT_V4L*/
 
 
-int vid_start (struct context *cnt)
+int vid_start(struct context *cnt)
 {
 	struct config *conf=&cnt->conf;
-        int fd_bktr=-1,fd_tuner=-1;
+	int fd_bktr=-1,fd_tuner=-1;
 	
 	if (conf->netcam_url)
 		return netcam_start(cnt);
@@ -811,11 +795,11 @@ int vid_start (struct context *cnt)
 		cnt->imgs.width=width;
 		cnt->imgs.height=height;
 
-		while (viddevs[++i]) {
+		while (viddevs[++i]) { 
 			if (!strcmp(conf->video_device, viddevs[i]->video_device)) {
-			  	int fd;
+				int fd;
 				cnt->imgs.type=viddevs[i]->v4l_fmt;
-				printf("[%d] vid_start cnt->imgs.type [%i]\n",cnt->threadnr,cnt->imgs.type);
+				motion_log(cnt, -1, 0, "vid_start cnt->imgs.type [%i]", cnt->imgs.type);
 				switch (cnt->imgs.type) {
 					case VIDEO_PALETTE_GREY:
 						cnt->imgs.motionsize=width*height;
@@ -825,7 +809,7 @@ int vid_start (struct context *cnt)
 					case VIDEO_PALETTE_YUV422:
 						cnt->imgs.type=VIDEO_PALETTE_YUV420P;
 					case VIDEO_PALETTE_YUV420P:
-						printf("[%d] VIDEO_PALETTE_YUV420P setting imgs.size and imgs.motionsize\n",cnt->threadnr);
+						motion_log(cnt, -1, 0, " VIDEO_PALETTE_YUV420P setting imgs.size and imgs.motionsize");
 						cnt->imgs.motionsize=width*height;
 						cnt->imgs.size=(width*height*3)/2;
 					break;
@@ -836,28 +820,28 @@ int vid_start (struct context *cnt)
 			}
 		}
 
-		viddevs=myrealloc(viddevs, sizeof(struct video_dev *)*(i+2), "vid_start");
-		viddevs[i]=mymalloc(sizeof(struct video_dev));
+		viddevs=myrealloc(cnt, viddevs, sizeof(struct video_dev *)*(i+2), "vid_start");
+		viddevs[i]=mymalloc(cnt, sizeof(struct video_dev));
 		viddevs[i+1]=NULL;
 
 		pthread_mutexattr_init(&viddevs[i]->attr);
 		pthread_mutex_init(&viddevs[i]->mutex, NULL);
 
 		fd_bktr=open(conf->video_device, O_RDWR);
-		if (fd_bktr <0) {
-			printf("[%d] Failed to open video device %s\n", cnt->threadnr, conf->video_device);
-			syslog(LOG_ERR, "[%d] Failed to open video device %s: %m", cnt->threadnr, conf->video_device);
+		if (fd_bktr <0) { 
+			motion_log(cnt, LOG_ERR, 1, "open video device %s",conf->video_device);
+			motion_log(cnt, LOG_ERR, 0, "Motion Exits.");
 			exit(1);
 		}
 
 		/* Only open tuner if freq > 0 FIXME ?! */
-		if (( frequency > 0 ) && ( input = IN_TV )){
+		if (( frequency > 0 ) && ( input = IN_TV )) {
 			fd_tuner=open(conf->tuner_device, O_RDWR);
-        		if (fd_bktr <0) {
-                		printf("[%d] Failed to open video device %s\n", cnt->threadnr, conf->tuner_device);
-                		syslog(LOG_ERR, "[%d] Failed to open video device %s: %m", cnt->threadnr, conf->tuner_device);
-                		exit(1);
-        		}
+			if (fd_bktr <0) { 
+				motion_log(cnt, LOG_ERR, 1, "open tuner device %s",conf->tuner_device);
+				motion_log(cnt, LOG_ERR, 0, "Motion Exits.");
+				exit(1);
+			}
 		}
 
 		viddevs[i]->video_device=conf->video_device;
@@ -876,15 +860,14 @@ int vid_start (struct context *cnt)
 		viddevs[i]->v4l_curbuffer=0;
 		viddevs[i]->v4l_maxbuffer=1;
 
-		if (!v4l_start (viddevs[i], width, height, input, norm, frequency, cnt)) {
+		if (!v4l_start (cnt, viddevs[i], width, height, input, norm, frequency)){ 
 			pthread_mutex_unlock(&vid_mutex);
 			return -1;
 		}
-
 	
 		cnt->imgs.type=viddevs[i]->v4l_fmt;
 	
-		switch (cnt->imgs.type) {
+		switch (cnt->imgs.type) { 
 			case VIDEO_PALETTE_GREY:
 				cnt->imgs.size=width*height;
 				cnt->imgs.motionsize=width*height;
@@ -893,7 +876,7 @@ int vid_start (struct context *cnt)
 			case VIDEO_PALETTE_YUV422:
 				cnt->imgs.type=VIDEO_PALETTE_YUV420P;
 			case VIDEO_PALETTE_YUV420P:
-				printf("[%d] VIDEO_PALETTE_YUV420P imgs.type\n", cnt->threadnr);
+				motion_log(cnt, -1, 0, "VIDEO_PALETTE_YUV420P imgs.type");
 				cnt->imgs.size=(width*height*3)/2;
 				cnt->imgs.motionsize=width*height;
 			break;
@@ -907,17 +890,27 @@ int vid_start (struct context *cnt)
 	return fd_bktr;
 }
 
-char *vid_next (struct context *cnt, char *map)
+
+/**
+ * vid_next fetches a video frame from a either v4l device or netcam
+ * Parameters:
+ *     cnt        Pointer to the context for this thread
+ *     map        Pointer to the buffer in which the function puts the new image
+ *
+ * Returns
+ *     0          Success
+ *    -1          Fatal V4L error
+ *    -2          Fatal Netcam error
+ *     1          Non fatal V4L error (not implemented)
+ *     2          Non fatal Netcam error
+ */
+int vid_next(struct context *cnt, char *map)
 {
 	struct config *conf=&cnt->conf;
-        char *ret=NULL;
+	int ret = -1;
 
 	if (conf->netcam_url) {
-		int retries=0;
-
-		ret=NULL;
-		while (!ret && retries++<100)
-			ret=netcam_next(cnt, map);
+		ret = netcam_next(cnt, map);
 		return ret;
 	}
 
@@ -936,9 +929,9 @@ char *vid_next (struct context *cnt, char *map)
 			break;
 
 	if (!viddevs[i])
-		return NULL;
+		return -1;
 
-	if (viddevs[i]->owner!=cnt->threadnr) {
+	if (viddevs[i]->owner!=cnt->threadnr) { 
 		pthread_mutex_lock(&viddevs[i]->mutex);
 		viddevs[i]->owner=cnt->threadnr;
 		viddevs[i]->frames=conf->roundrobin_frames;
@@ -947,17 +940,18 @@ char *vid_next (struct context *cnt, char *map)
 	}
 
 
-	v4l_set_input (viddevs[i], map, width, height, conf->input, conf->norm, conf->roundrobin_skip, conf->frequency, cnt);
-	ret=v4l_next (viddevs[i], map, width, height, cnt);
+	v4l_set_input(cnt, viddevs[i], map, width, height, conf->input, conf->norm,
+	              conf->roundrobin_skip, conf->frequency);
+	ret = v4l_next(cnt, viddevs[i], map, width, height);
 
-	if (--viddevs[i]->frames <= 0) {
+	if (--viddevs[i]->frames <= 0) { 
 		viddevs[i]->owner=-1;
 		pthread_mutex_unlock(&viddevs[i]->mutex);
 	}
 	
- 	if(cnt->rotate_data.degrees > 0) {
+ 	if(cnt->rotate_data.degrees > 0){ 
 		/* rotate the image as specified */
-		rotate_map(map, cnt);
+		rotate_map(cnt, map);
  	}
 	
 #endif /*WITHOUT_V4L*/
