@@ -80,17 +80,17 @@ struct video_dev {
 };
 
 /* video functions, video_freebsd.c */
-int vid_start (struct context *);
-char *vid_next (struct context *, char *map);
+int vid_start(struct context *);
+int vid_next(struct context *, char *map);
 
 #ifndef WITHOUT_V4L
-void vid_init(void);
+void vid_init(struct context *);
 void vid_close(void);
 void vid_cleanup(void);
 #endif
 
 /* Network camera functions, netcam.c */
-int netcam_start (struct context *);
-unsigned char *netcam_next (struct context *, char *);
+int netcam_start(struct context *);
+int netcam_next(struct context *, unsigned char *);
 
 #endif /* _INCLUDE_VIDEO_FREEBSD_H */
